# Auto-generated by scripts/scaffold_rules.py
from . import registry


@registry.register("7.1.1", text="युवोरनाकौ।")
def rule_7_1_1(ctx=None):
    """
    7.1.1: युवोरनाकौ।
    """
    pass


@registry.register("7.1.2", text="आयनेयीनीयियः फढखच्छघां प्रत्ययादीनाम् ।")
def rule_7_1_2(ctx=None):
    """
    7.1.2: आयनेयीनीयियः फढखच्छघां प्रत्ययादीनाम् ।
    """
    pass


@registry.register("7.1.3", text="झोऽन्तः ।")
def rule_7_1_3(ctx=None):
    """
    7.1.3: झोऽन्तः ।
    """
    pass


@registry.register("7.1.4", text="अदभ्यस्तात् ।")
def rule_7_1_4(ctx=None):
    """
    7.1.4: अदभ्यस्तात् ।
    """
    pass


@registry.register("7.1.5", text="आत्मनेपदेष्वनतः ।")
def rule_7_1_5(ctx=None):
    """
    7.1.5: आत्मनेपदेष्वनतः ।
    """
    pass


@registry.register("7.1.6", text="शीङोरुट् ।")
def rule_7_1_6(ctx=None):
    """
    7.1.6: शीङोरुट् ।
    """
    pass


@registry.register("7.1.7", text="वेत्तेर्विभाषा ।")
def rule_7_1_7(ctx=None):
    """
    7.1.7: वेत्तेर्विभाषा ।
    """
    pass


@registry.register("7.1.8", text="बहुलं छन्दसि ।")
def rule_7_1_8(ctx=None):
    """
    7.1.8: बहुलं छन्दसि ।
    """
    pass


@registry.register("7.1.9", text="अतोभिस ऐस् ।")
def rule_7_1_9(ctx=None):
    """
    7.1.9: अतोभिस ऐस् ।
    """
    pass


@registry.register("7.1.10", text="बहुलं छन्दसि ।")
def rule_7_1_10(ctx=None):
    """
    7.1.10: बहुलं छन्दसि ।
    """
    pass


@registry.register("7.1.11", text="नेदमदसोरकोः ।")
def rule_7_1_11(ctx=None):
    """
    7.1.11: नेदमदसोरकोः ।
    """
    pass


@registry.register("7.1.12", text="टाङसिङसामिनात्स्याः ।")
def rule_7_1_12(ctx=None):
    """
    7.1.12: टाङसिङसामिनात्स्याः ।
    """
    pass


@registry.register("7.1.13", text="ङेर्यः ।")
def rule_7_1_13(ctx=None):
    """
    7.1.13: ङेर्यः ।
    """
    pass


@registry.register("7.1.14", text="सर्वनाम्नः स्मै।")
def rule_7_1_14(ctx=None):
    """
    7.1.14: सर्वनाम्नः स्मै।
    """
    pass


@registry.register("7.1.15", text="ङसिङ्योः स्मात्स्मिनौ।")
def rule_7_1_15(ctx=None):
    """
    7.1.15: ङसिङ्योः स्मात्स्मिनौ।
    """
    pass


@registry.register("7.1.16", text="पूर्वादिभ्योनवभ्योवा ।")
def rule_7_1_16(ctx=None):
    """
    7.1.16: पूर्वादिभ्योनवभ्योवा ।
    """
    pass


@registry.register("7.1.17", text="जसः शी ।")
def rule_7_1_17(ctx=None):
    """
    7.1.17: जसः शी ।
    """
    pass


@registry.register("7.1.18", text="औङ आपः ।")
def rule_7_1_18(ctx=None):
    """
    7.1.18: औङ आपः ।
    """
    pass


@registry.register("7.1.19", text="नपुंसकाच्च ।")
def rule_7_1_19(ctx=None):
    """
    7.1.19: नपुंसकाच्च ।
    """
    pass


@registry.register("7.1.20", text="जस्शसोः शिः ।")
def rule_7_1_20(ctx=None):
    """
    7.1.20: जस्शसोः शिः ।
    """
    pass


@registry.register("7.1.21", text="अष्टाभ्य औश् ।")
def rule_7_1_21(ctx=None):
    """
    7.1.21: अष्टाभ्य औश् ।
    """
    pass


@registry.register("7.1.22", text="षड्भ्योलुक् ।")
def rule_7_1_22(ctx=None):
    """
    7.1.22: षड्भ्योलुक् ।
    """
    pass


@registry.register("7.1.23", text="स्वमोर्नपुंसकात् ।")
def rule_7_1_23(ctx=None):
    """
    7.1.23: स्वमोर्नपुंसकात् ।
    """
    pass


@registry.register("7.1.24", text="अतोऽम् ।")
def rule_7_1_24(ctx=None):
    """
    7.1.24: अतोऽम् ।
    """
    pass


@registry.register("7.1.25", text="अद्ड् डतरादिभ्यः पञ्चभ्यः ।")
def rule_7_1_25(ctx=None):
    """
    7.1.25: अद्ड् डतरादिभ्यः पञ्चभ्यः ।
    """
    pass


@registry.register("7.1.26", text="नेतराच्छन्दसि ।")
def rule_7_1_26(ctx=None):
    """
    7.1.26: नेतराच्छन्दसि ।
    """
    pass


@registry.register("7.1.27", text="युष्मदस्मद्भ्यां ङसोऽश् ।")
def rule_7_1_27(ctx=None):
    """
    7.1.27: युष्मदस्मद्भ्यां ङसोऽश् ।
    """
    pass


@registry.register("7.1.28", text="ङे प्रथमयोरम् ।")
def rule_7_1_28(ctx=None):
    """
    7.1.28: ङे प्रथमयोरम् ।
    """
    pass


@registry.register("7.1.29", text="शसोन ।")
def rule_7_1_29(ctx=None):
    """
    7.1.29: शसोन ।
    """
    pass


@registry.register("7.1.30", text="भ्यसः भ्यम् ।")
def rule_7_1_30(ctx=None):
    """
    7.1.30: भ्यसः भ्यम् ।
    """
    pass


@registry.register("7.1.31", text="पञ्चम्या अत् ।")
def rule_7_1_31(ctx=None):
    """
    7.1.31: पञ्चम्या अत् ।
    """
    pass


@registry.register("7.1.32", text="एकवचनस्य च ।")
def rule_7_1_32(ctx=None):
    """
    7.1.32: एकवचनस्य च ।
    """
    pass


@registry.register("7.1.33", text="साम आकम् ।")
def rule_7_1_33(ctx=None):
    """
    7.1.33: साम आकम् ।
    """
    pass


@registry.register("7.1.34", text="आत औणलः ।")
def rule_7_1_34(ctx=None):
    """
    7.1.34: आत औणलः ।
    """
    pass


@registry.register("7.1.35", text="तुह्योस्तातङाशिष्यन्यतरस्याम् ।")
def rule_7_1_35(ctx=None):
    """
    7.1.35: तुह्योस्तातङाशिष्यन्यतरस्याम् ।
    """
    pass


@registry.register("7.1.36", text="विदेः शतुर्वसुः ।")
def rule_7_1_36(ctx=None):
    """
    7.1.36: विदेः शतुर्वसुः ।
    """
    pass


@registry.register("7.1.37", text="समासेऽनञ्पूर्वे क्त्वोल्यप् ।")
def rule_7_1_37(ctx=None):
    """
    7.1.37: समासेऽनञ्पूर्वे क्त्वोल्यप् ।
    """
    pass


@registry.register("7.1.38", text="क्त्वाऽपि छन्दसि ।")
def rule_7_1_38(ctx=None):
    """
    7.1.38: क्त्वाऽपि छन्दसि ।
    """
    pass


@registry.register("7.1.39", text="सुपां सुलुक्पूर्वसवर्णाऽऽच्छेयाडाड्यायाजालः ।")
def rule_7_1_39(ctx=None):
    """
    7.1.39: सुपां सुलुक्पूर्वसवर्णाऽऽच्छेयाडाड्यायाजालः ।
    """
    pass


@registry.register("7.1.40", text="अमोमश् ।")
def rule_7_1_40(ctx=None):
    """
    7.1.40: अमोमश् ।
    """
    pass


@registry.register("7.1.41", text="लोपस्त आत्मनेपदेषु।")
def rule_7_1_41(ctx=None):
    """
    7.1.41: लोपस्त आत्मनेपदेषु।
    """
    pass


@registry.register("7.1.42", text="ध्वमोध्वात् ।")
def rule_7_1_42(ctx=None):
    """
    7.1.42: ध्वमोध्वात् ।
    """
    pass


@registry.register("7.1.43", text="यजध्वैनमिति च ।")
def rule_7_1_43(ctx=None):
    """
    7.1.43: यजध्वैनमिति च ।
    """
    pass


@registry.register("7.1.44", text="तस्य तात् ।")
def rule_7_1_44(ctx=None):
    """
    7.1.44: तस्य तात् ।
    """
    pass


@registry.register("7.1.45", text="तप्तनप्तनथनाश्च ।")
def rule_7_1_45(ctx=None):
    """
    7.1.45: तप्तनप्तनथनाश्च ।
    """
    pass


@registry.register("7.1.46", text="इदन्तोमसि ।")
def rule_7_1_46(ctx=None):
    """
    7.1.46: इदन्तोमसि ।
    """
    pass


@registry.register("7.1.47", text="क्त्वोयक् ।")
def rule_7_1_47(ctx=None):
    """
    7.1.47: क्त्वोयक् ।
    """
    pass


@registry.register("7.1.48", text="इष्ट्वीनमिति च ।")
def rule_7_1_48(ctx=None):
    """
    7.1.48: इष्ट्वीनमिति च ।
    """
    pass


@registry.register("7.1.49", text="स्नात्व्यादयश्च ।")
def rule_7_1_49(ctx=None):
    """
    7.1.49: स्नात्व्यादयश्च ।
    """
    pass


@registry.register("7.1.50", text="आज्जसेरसुक् ।")
def rule_7_1_50(ctx=None):
    """
    7.1.50: आज्जसेरसुक् ।
    """
    pass


@registry.register("7.1.51", text="अश्वक्षीरवृषलवणानामात्मप्रीतौक्यचि ।")
def rule_7_1_51(ctx=None):
    """
    7.1.51: अश्वक्षीरवृषलवणानामात्मप्रीतौक्यचि ।
    """
    pass


@registry.register("7.1.52", text="आमि सर्वनाम्नः सुट् ।")
def rule_7_1_52(ctx=None):
    """
    7.1.52: आमि सर्वनाम्नः सुट् ।
    """
    pass


@registry.register("7.1.53", text="त्रेस्त्रयः ।")
def rule_7_1_53(ctx=None):
    """
    7.1.53: त्रेस्त्रयः ।
    """
    pass


@registry.register("7.1.54", text="ह्रस्वनद्यापोनुट् ।")
def rule_7_1_54(ctx=None):
    """
    7.1.54: ह्रस्वनद्यापोनुट् ।
    """
    pass


@registry.register("7.1.55", text="षट्चतुर्भ्यश्च ।")
def rule_7_1_55(ctx=None):
    """
    7.1.55: षट्चतुर्भ्यश्च ।
    """
    pass


@registry.register("7.1.56", text="श्रीग्रामण्योश्छन्दसि ।")
def rule_7_1_56(ctx=None):
    """
    7.1.56: श्रीग्रामण्योश्छन्दसि ।
    """
    pass


@registry.register("7.1.57", text="गोः पादान्ते।")
def rule_7_1_57(ctx=None):
    """
    7.1.57: गोः पादान्ते।
    """
    pass


@registry.register("7.1.58", text="इदितोनुम् धातोः ।")
def rule_7_1_58(ctx=None):
    """
    7.1.58: इदितोनुम् धातोः ।
    """
    pass


@registry.register("7.1.59", text="शेमुचादीनाम् ।")
def rule_7_1_59(ctx=None):
    """
    7.1.59: शेमुचादीनाम् ।
    """
    pass


@registry.register("7.1.60", text="मस्जिनशोर्झलि ।")
def rule_7_1_60(ctx=None):
    """
    7.1.60: मस्जिनशोर्झलि ।
    """
    pass


@registry.register("7.1.61", text="रधिजभोरचि ।")
def rule_7_1_61(ctx=None):
    """
    7.1.61: रधिजभोरचि ।
    """
    pass


@registry.register("7.1.62", text="नेट्यलिटि रधेः ।")
def rule_7_1_62(ctx=None):
    """
    7.1.62: नेट्यलिटि रधेः ।
    """
    pass


@registry.register("7.1.63", text="रभेरशब्लिटोः ।")
def rule_7_1_63(ctx=None):
    """
    7.1.63: रभेरशब्लिटोः ।
    """
    pass


@registry.register("7.1.64", text="लभेश्च ।")
def rule_7_1_64(ctx=None):
    """
    7.1.64: लभेश्च ।
    """
    pass


@registry.register("7.1.65", text="आङोयि ।")
def rule_7_1_65(ctx=None):
    """
    7.1.65: आङोयि ।
    """
    pass


@registry.register("7.1.66", text="उपात् प्रशंसायाम् ।")
def rule_7_1_66(ctx=None):
    """
    7.1.66: उपात् प्रशंसायाम् ।
    """
    pass


@registry.register("7.1.67", text="उपसर्गात् खल्घञोः ।")
def rule_7_1_67(ctx=None):
    """
    7.1.67: उपसर्गात् खल्घञोः ।
    """
    pass


@registry.register("7.1.68", text="न सुदुर्भ्यां केवलाभ्याम् ।")
def rule_7_1_68(ctx=None):
    """
    7.1.68: न सुदुर्भ्यां केवलाभ्याम् ।
    """
    pass


@registry.register("7.1.69", text="विभाषा चिण्णमुलोः ।")
def rule_7_1_69(ctx=None):
    """
    7.1.69: विभाषा चिण्णमुलोः ।
    """
    pass


@registry.register("7.1.70", text="उगिदचां सर्वनामस्थानेऽधातोः ।")
def rule_7_1_70(ctx=None):
    """
    7.1.70: उगिदचां सर्वनामस्थानेऽधातोः ।
    """
    pass


@registry.register("7.1.71", text="युजेरसमासे।")
def rule_7_1_71(ctx=None):
    """
    7.1.71: युजेरसमासे।
    """
    pass


@registry.register("7.1.72", text="नपुंसकस्य झलचः ।")
def rule_7_1_72(ctx=None):
    """
    7.1.72: नपुंसकस्य झलचः ।
    """
    pass


@registry.register("7.1.73", text="इकोऽचि विभक्तौ।")
def rule_7_1_73(ctx=None):
    """
    7.1.73: इकोऽचि विभक्तौ।
    """
    pass


@registry.register("7.1.74", text="तृतीयाऽऽदिषुभाषितपुंस्कं पुंवद्गालवस्य ।")
def rule_7_1_74(ctx=None):
    """
    7.1.74: तृतीयाऽऽदिषुभाषितपुंस्कं पुंवद्गालवस्य ।
    """
    pass


@registry.register("7.1.75", text="अस्थिदधिसक्थ्यक्ष्णामनङुदात्तः ।")
def rule_7_1_75(ctx=None):
    """
    7.1.75: अस्थिदधिसक्थ्यक्ष्णामनङुदात्तः ।
    """
    pass


@registry.register("7.1.76", text="छन्दस्यपि दृश्यते।")
def rule_7_1_76(ctx=None):
    """
    7.1.76: छन्दस्यपि दृश्यते।
    """
    pass


@registry.register("7.1.77", text="ई च द्विवचने।")
def rule_7_1_77(ctx=None):
    """
    7.1.77: ई च द्विवचने।
    """
    pass


@registry.register("7.1.78", text="नाभ्यस्ताच्छतुः ।")
def rule_7_1_78(ctx=None):
    """
    7.1.78: नाभ्यस्ताच्छतुः ।
    """
    pass


@registry.register("7.1.79", text="वा नपुंसकस्य ।")
def rule_7_1_79(ctx=None):
    """
    7.1.79: वा नपुंसकस्य ।
    """
    pass


@registry.register("7.1.80", text="आच्छीनद्योर्नुम् ।")
def rule_7_1_80(ctx=None):
    """
    7.1.80: आच्छीनद्योर्नुम् ।
    """
    pass


@registry.register("7.1.81", text="शप्श्यनोर्नित्यम् ।")
def rule_7_1_81(ctx=None):
    """
    7.1.81: शप्श्यनोर्नित्यम् ।
    """
    pass


@registry.register("7.1.82", text="सावनडुहः ।")
def rule_7_1_82(ctx=None):
    """
    7.1.82: सावनडुहः ।
    """
    pass


@registry.register("7.1.83", text="दृक्स्ववस्स्वतवसां छन्दसि ।")
def rule_7_1_83(ctx=None):
    """
    7.1.83: दृक्स्ववस्स्वतवसां छन्दसि ।
    """
    pass


@registry.register("7.1.84", text="दिव औत् ।")
def rule_7_1_84(ctx=None):
    """
    7.1.84: दिव औत् ।
    """
    pass


@registry.register("7.1.85", text="पथिमथ्यृभुक्षामात् ।")
def rule_7_1_85(ctx=None):
    """
    7.1.85: पथिमथ्यृभुक्षामात् ।
    """
    pass


@registry.register("7.1.86", text="इतोऽत् सर्वनामस्थाने।")
def rule_7_1_86(ctx=None):
    """
    7.1.86: इतोऽत् सर्वनामस्थाने।
    """
    pass


@registry.register("7.1.87", text="थोन्थः ।")
def rule_7_1_87(ctx=None):
    """
    7.1.87: थोन्थः ।
    """
    pass


@registry.register("7.1.88", text="भस्य टेर्लोपः ।")
def rule_7_1_88(ctx=None):
    """
    7.1.88: भस्य टेर्लोपः ।
    """
    pass


@registry.register("7.1.89", text="पुंसोऽसुङ् ।")
def rule_7_1_89(ctx=None):
    """
    7.1.89: पुंसोऽसुङ् ।
    """
    pass


@registry.register("7.1.90", text="गोतोणित् ।")
def rule_7_1_90(ctx=None):
    """
    7.1.90: गोतोणित् ।
    """
    pass


@registry.register("7.1.91", text="णलुत्तमो वा ।")
def rule_7_1_91(ctx=None):
    """
    7.1.91: णलुत्तमो वा ।
    """
    pass


@registry.register("7.1.92", text="सख्युरसम्बुद्धौ।")
def rule_7_1_92(ctx=None):
    """
    7.1.92: सख्युरसम्बुद्धौ।
    """
    pass


@registry.register("7.1.93", text="अनङ् सौ।")
def rule_7_1_93(ctx=None):
    """
    7.1.93: अनङ् सौ।
    """
    pass


@registry.register("7.1.94", text="ऋदुशनस्पुरुदंशोऽनेहसां च ।")
def rule_7_1_94(ctx=None):
    """
    7.1.94: ऋदुशनस्पुरुदंशोऽनेहसां च ।
    """
    pass


@registry.register("7.1.95", text="तृज्वत् क्रोष्टुः ।")
def rule_7_1_95(ctx=None):
    """
    7.1.95: तृज्वत् क्रोष्टुः ।
    """
    pass


@registry.register("7.1.96", text="स्त्रियां च ।")
def rule_7_1_96(ctx=None):
    """
    7.1.96: स्त्रियां च ।
    """
    pass


@registry.register("7.1.97", text="विभाषा तृतीयाऽऽदिष्वचि ।")
def rule_7_1_97(ctx=None):
    """
    7.1.97: विभाषा तृतीयाऽऽदिष्वचि ।
    """
    pass


@registry.register("7.1.98", text="चतुरनडुहोरामुदात्तः ।")
def rule_7_1_98(ctx=None):
    """
    7.1.98: चतुरनडुहोरामुदात्तः ।
    """
    pass


@registry.register("7.1.99", text="अम् सम्बुद्धौ।")
def rule_7_1_99(ctx=None):
    """
    7.1.99: अम् सम्बुद्धौ।
    """
    pass


@registry.register("7.1.100", text="ॠत इद्धातोः ।")
def rule_7_1_100(ctx=None):
    """
    7.1.100: ॠत इद्धातोः ।
    """
    pass


@registry.register("7.1.101", text="उपधायाश्च ।")
def rule_7_1_101(ctx=None):
    """
    7.1.101: उपधायाश्च ।
    """
    pass


@registry.register("7.1.102", text="उदोष्ठ्यपूर्वस्य ।")
def rule_7_1_102(ctx=None):
    """
    7.1.102: उदोष्ठ्यपूर्वस्य ।
    """
    pass


@registry.register("7.1.103", text="बहुलं छन्दसि ।")
def rule_7_1_103(ctx=None):
    """
    7.1.103: बहुलं छन्दसि ।
    """
    pass


@registry.register("7.2.1", text="सिचि वृद्धिः परस्मैपदेषु।")
def rule_7_2_1(ctx=None):
    """
    7.2.1: सिचि वृद्धिः परस्मैपदेषु।
    """
    pass


@registry.register("7.2.2", text="अतोर्लान्तस्य ।")
def rule_7_2_2(ctx=None):
    """
    7.2.2: अतोर्लान्तस्य ।
    """
    pass


@registry.register("7.2.3", text="वदव्रजहलन्तस्याचः ।")
def rule_7_2_3(ctx=None):
    """
    7.2.3: वदव्रजहलन्तस्याचः ।
    """
    pass


@registry.register("7.2.4", text="नेटि ।")
def rule_7_2_4(ctx=None):
    """
    7.2.4: नेटि ।
    """
    pass


@registry.register("7.2.5", text="ह्म्यन्तक्षणश्वसजागृणिश्व्येदिताम् ।")
def rule_7_2_5(ctx=None):
    """
    7.2.5: ह्म्यन्तक्षणश्वसजागृणिश्व्येदिताम् ।
    """
    pass


@registry.register("7.2.6", text="ऊर्णोतेर्विभाषा ।")
def rule_7_2_6(ctx=None):
    """
    7.2.6: ऊर्णोतेर्विभाषा ।
    """
    pass


@registry.register("7.2.7", text="अतोहलादेर्लघोः ।")
def rule_7_2_7(ctx=None):
    """
    7.2.7: अतोहलादेर्लघोः ।
    """
    pass


@registry.register("7.2.8", text="नेड् वशि कृति ।")
def rule_7_2_8(ctx=None):
    """
    7.2.8: नेड् वशि कृति ।
    """
    pass


@registry.register("7.2.9", text="तितुत्रतथसिसुसरकसेषुच ।")
def rule_7_2_9(ctx=None):
    """
    7.2.9: तितुत्रतथसिसुसरकसेषुच ।
    """
    pass


@registry.register("7.2.10", text="एकाच उपदेशेऽनुदात्तात् ।")
def rule_7_2_10(ctx=None):
    """
    7.2.10: एकाच उपदेशेऽनुदात्तात् ।
    """
    pass


@registry.register("7.2.11", text="श्र्युकः किति ।")
def rule_7_2_11(ctx=None):
    """
    7.2.11: श्र्युकः किति ।
    """
    pass


@registry.register("7.2.12", text="सनि ग्रहगुहोश्च ।")
def rule_7_2_12(ctx=None):
    """
    7.2.12: सनि ग्रहगुहोश्च ।
    """
    pass


@registry.register("7.2.13", text="कृसृभृवृस्तुद्रुस्रुश्रुवोलिटि ।")
def rule_7_2_13(ctx=None):
    """
    7.2.13: कृसृभृवृस्तुद्रुस्रुश्रुवोलिटि ।
    """
    pass


@registry.register("7.2.14", text="श्वीदितोनिष्ठायाम् ।")
def rule_7_2_14(ctx=None):
    """
    7.2.14: श्वीदितोनिष्ठायाम् ।
    """
    pass


@registry.register("7.2.15", text="यस्य विभाषा ।")
def rule_7_2_15(ctx=None):
    """
    7.2.15: यस्य विभाषा ।
    """
    pass


@registry.register("7.2.16", text="आदितश्च ।")
def rule_7_2_16(ctx=None):
    """
    7.2.16: आदितश्च ।
    """
    pass


@registry.register("7.2.17", text="विभाषा भावादिकर्मणोः ।")
def rule_7_2_17(ctx=None):
    """
    7.2.17: विभाषा भावादिकर्मणोः ।
    """
    pass


@registry.register("7.2.18", text="क्षुब्धस्वान्तध्वान्तलग्नम्लिष्टविरिब्धफाण्टबाढानि मन्थमनस्तमःसक्ताविस्पष्टस्वरानायासभृशेषु।")
def rule_7_2_18(ctx=None):
    """
    7.2.18: क्षुब्धस्वान्तध्वान्तलग्नम्लिष्टविरिब्धफाण्टबाढानि मन्थमनस्तमःसक्ताविस्पष्टस्वरानायासभृशेषु।
    """
    pass


@registry.register("7.2.19", text="धृषिशसी वैयात्ये।")
def rule_7_2_19(ctx=None):
    """
    7.2.19: धृषिशसी वैयात्ये।
    """
    pass


@registry.register("7.2.20", text="दृढः स्थूलबलयोः ।")
def rule_7_2_20(ctx=None):
    """
    7.2.20: दृढः स्थूलबलयोः ।
    """
    pass


@registry.register("7.2.21", text="प्रभौपरिवृढः ।")
def rule_7_2_21(ctx=None):
    """
    7.2.21: प्रभौपरिवृढः ।
    """
    pass


@registry.register("7.2.22", text="कृच्छ्रगहनयोः कषः ।")
def rule_7_2_22(ctx=None):
    """
    7.2.22: कृच्छ्रगहनयोः कषः ।
    """
    pass


@registry.register("7.2.23", text="घुषिरविशब्दने।")
def rule_7_2_23(ctx=None):
    """
    7.2.23: घुषिरविशब्दने।
    """
    pass


@registry.register("7.2.24", text="अर्देः संनिविभ्यः ।")
def rule_7_2_24(ctx=None):
    """
    7.2.24: अर्देः संनिविभ्यः ।
    """
    pass


@registry.register("7.2.25", text="अभेश्चाविदूर्ये ।")
def rule_7_2_25(ctx=None):
    """
    7.2.25: अभेश्चाविदूर्ये ।
    """
    pass


@registry.register("7.2.26", text="णेरध्ययनेवृत्तम् ।")
def rule_7_2_26(ctx=None):
    """
    7.2.26: णेरध्ययनेवृत्तम् ।
    """
    pass


@registry.register("7.2.27", text="वा दान्तशान्तपूर्णदस्तस्पष्टच्छन्नज्ञप्ताः ।")
def rule_7_2_27(ctx=None):
    """
    7.2.27: वा दान्तशान्तपूर्णदस्तस्पष्टच्छन्नज्ञप्ताः ।
    """
    pass


@registry.register("7.2.28", text="रुष्यमत्वरसंघुषास्वनाम् ।")
def rule_7_2_28(ctx=None):
    """
    7.2.28: रुष्यमत्वरसंघुषास्वनाम् ।
    """
    pass


@registry.register("7.2.29", text="हृषेर्लोमसु।")
def rule_7_2_29(ctx=None):
    """
    7.2.29: हृषेर्लोमसु।
    """
    pass


@registry.register("7.2.30", text="अपचितश्च ।")
def rule_7_2_30(ctx=None):
    """
    7.2.30: अपचितश्च ।
    """
    pass


@registry.register("7.2.31", text="ह्रु ह्वरेश्छन्दसि ।")
def rule_7_2_31(ctx=None):
    """
    7.2.31: ह्रु ह्वरेश्छन्दसि ।
    """
    pass


@registry.register("7.2.32", text="अपरिह्वृताश्च ।")
def rule_7_2_32(ctx=None):
    """
    7.2.32: अपरिह्वृताश्च ।
    """
    pass


@registry.register("7.2.33", text="सोमेह्वरितः ।")
def rule_7_2_33(ctx=None):
    """
    7.2.33: सोमेह्वरितः ।
    """
    pass


@registry.register("7.2.34", text="ग्रसितस्कभितस्तभितोत्तभितचत्तविकस्तविशस्तॄ शंस्तृशास्तृतरुतृतरूतृवरुतृवरूतृवरुत्रीरुज्ज्वलितिक्षरिति क्षमितिवमित्यमितीति च ।")
def rule_7_2_34(ctx=None):
    """
    7.2.34: ग्रसितस्कभितस्तभितोत्तभितचत्तविकस्तविशस्तॄ शंस्तृशास्तृतरुतृतरूतृवरुतृवरूतृवरुत्रीरुज्ज्वलितिक्षरिति क्षमितिवमित्यमितीति च ।
    """
    pass


@registry.register("7.2.35", text="आर्धधातुकस्येड् वलादेः ।")
def rule_7_2_35(ctx=None):
    """
    7.2.35: आर्धधातुकस्येड् वलादेः ।
    """
    pass


@registry.register("7.2.36", text="स्नुक्रमोरनात्मनेपदनिमित्ते।")
def rule_7_2_36(ctx=None):
    """
    7.2.36: स्नुक्रमोरनात्मनेपदनिमित्ते।
    """
    pass


@registry.register("7.2.37", text="ग्रहोऽलिटि दीर्घः ।")
def rule_7_2_37(ctx=None):
    """
    7.2.37: ग्रहोऽलिटि दीर्घः ।
    """
    pass


@registry.register("7.2.38", text="वॄतोवा ।")
def rule_7_2_38(ctx=None):
    """
    7.2.38: वॄतोवा ।
    """
    pass


@registry.register("7.2.39", text="न लिङि ।")
def rule_7_2_39(ctx=None):
    """
    7.2.39: न लिङि ।
    """
    pass


@registry.register("7.2.40", text="सिचि च परस्मैपदेषु।")
def rule_7_2_40(ctx=None):
    """
    7.2.40: सिचि च परस्मैपदेषु।
    """
    pass


@registry.register("7.2.41", text="इट् सनि वा ।")
def rule_7_2_41(ctx=None):
    """
    7.2.41: इट् सनि वा ।
    """
    pass


@registry.register("7.2.42", text="लिङ्सिचोरात्मनेपदेषु।")
def rule_7_2_42(ctx=None):
    """
    7.2.42: लिङ्सिचोरात्मनेपदेषु।
    """
    pass


@registry.register("7.2.43", text="ऋतश्च संयोगादेः ।")
def rule_7_2_43(ctx=None):
    """
    7.2.43: ऋतश्च संयोगादेः ।
    """
    pass


@registry.register("7.2.44", text="स्वरतिसूतिसूयतिधूञूदितोवा ।")
def rule_7_2_44(ctx=None):
    """
    7.2.44: स्वरतिसूतिसूयतिधूञूदितोवा ।
    """
    pass


@registry.register("7.2.45", text="रधादिभ्यश्च ।")
def rule_7_2_45(ctx=None):
    """
    7.2.45: रधादिभ्यश्च ।
    """
    pass


@registry.register("7.2.46", text="निरः कुषः ।")
def rule_7_2_46(ctx=None):
    """
    7.2.46: निरः कुषः ।
    """
    pass


@registry.register("7.2.47", text="इण्निष्ठायाम् ।")
def rule_7_2_47(ctx=None):
    """
    7.2.47: इण्निष्ठायाम् ।
    """
    pass


@registry.register("7.2.48", text="तीषसहलुभरुषरिषः ।")
def rule_7_2_48(ctx=None):
    """
    7.2.48: तीषसहलुभरुषरिषः ।
    """
    pass


@registry.register("7.2.49", text="सनीवन्तर्धभ्रस्जदम्भुश्रिस्वृयूर्णुभरज्ञपिसनाम् ।")
def rule_7_2_49(ctx=None):
    """
    7.2.49: सनीवन्तर्धभ्रस्जदम्भुश्रिस्वृयूर्णुभरज्ञपिसनाम् ।
    """
    pass


@registry.register("7.2.50", text="क्लिशः क्त्वानिष्ठयोः ।")
def rule_7_2_50(ctx=None):
    """
    7.2.50: क्लिशः क्त्वानिष्ठयोः ।
    """
    pass


@registry.register("7.2.51", text="पूङश्च ।")
def rule_7_2_51(ctx=None):
    """
    7.2.51: पूङश्च ।
    """
    pass


@registry.register("7.2.52", text="वसतिक्षुधोरिट् ।")
def rule_7_2_52(ctx=None):
    """
    7.2.52: वसतिक्षुधोरिट् ।
    """
    pass


@registry.register("7.2.53", text="अञ्चेः पूजायाम् ।")
def rule_7_2_53(ctx=None):
    """
    7.2.53: अञ्चेः पूजायाम् ।
    """
    pass


@registry.register("7.2.54", text="लुभो विमोचने।")
def rule_7_2_54(ctx=None):
    """
    7.2.54: लुभो विमोचने।
    """
    pass


@registry.register("7.2.55", text="जॄव्रश्च्योः क्त्वि ।")
def rule_7_2_55(ctx=None):
    """
    7.2.55: जॄव्रश्च्योः क्त्वि ।
    """
    pass


@registry.register("7.2.56", text="उदितोवा ।")
def rule_7_2_56(ctx=None):
    """
    7.2.56: उदितोवा ।
    """
    pass


@registry.register("7.2.57", text="सेऽसिचि कृतचृतच्छृदतृदनृतः ।")
def rule_7_2_57(ctx=None):
    """
    7.2.57: सेऽसिचि कृतचृतच्छृदतृदनृतः ।
    """
    pass


@registry.register("7.2.58", text="गमेरिट् परस्मैपदेषु।")
def rule_7_2_58(ctx=None):
    """
    7.2.58: गमेरिट् परस्मैपदेषु।
    """
    pass


@registry.register("7.2.59", text="न वृद्भ्यश्चतुर्भ्यः ।")
def rule_7_2_59(ctx=None):
    """
    7.2.59: न वृद्भ्यश्चतुर्भ्यः ।
    """
    pass


@registry.register("7.2.60", text="तासि च कॢपः ।")
def rule_7_2_60(ctx=None):
    """
    7.2.60: तासि च कॢपः ।
    """
    pass


@registry.register("7.2.61", text="अचस्तास्वत् थल्यनिटोनित्यम् ।")
def rule_7_2_61(ctx=None):
    """
    7.2.61: अचस्तास्वत् थल्यनिटोनित्यम् ।
    """
    pass


@registry.register("7.2.62", text="उपदेशेऽत्वतः ।")
def rule_7_2_62(ctx=None):
    """
    7.2.62: उपदेशेऽत्वतः ।
    """
    pass


@registry.register("7.2.63", text="ऋतोभारद्वाजस्य ।")
def rule_7_2_63(ctx=None):
    """
    7.2.63: ऋतोभारद्वाजस्य ।
    """
    pass


@registry.register("7.2.64", text="बभूथाततन्थजगृम्भववर्थेति निगमे।")
def rule_7_2_64(ctx=None):
    """
    7.2.64: बभूथाततन्थजगृम्भववर्थेति निगमे।
    """
    pass


@registry.register("7.2.65", text="विभाषा सृजिदृषोः ।")
def rule_7_2_65(ctx=None):
    """
    7.2.65: विभाषा सृजिदृषोः ।
    """
    pass


@registry.register("7.2.66", text="इडत्त्यर्तिव्ययतीनाम् ।")
def rule_7_2_66(ctx=None):
    """
    7.2.66: इडत्त्यर्तिव्ययतीनाम् ।
    """
    pass


@registry.register("7.2.67", text="वस्वेकाजाद्घसाम् ।")
def rule_7_2_67(ctx=None):
    """
    7.2.67: वस्वेकाजाद्घसाम् ।
    """
    pass


@registry.register("7.2.68", text="विभाषा गमहनविदविशाम् ।")
def rule_7_2_68(ctx=None):
    """
    7.2.68: विभाषा गमहनविदविशाम् ।
    """
    pass


@registry.register("7.2.69", text="सनिंससनिवांसम् ।")
def rule_7_2_69(ctx=None):
    """
    7.2.69: सनिंससनिवांसम् ।
    """
    pass


@registry.register("7.2.70", text="ऋद्धनोः स्ये।")
def rule_7_2_70(ctx=None):
    """
    7.2.70: ऋद्धनोः स्ये।
    """
    pass


@registry.register("7.2.71", text="अञ्जेः सिचि ।")
def rule_7_2_71(ctx=None):
    """
    7.2.71: अञ्जेः सिचि ।
    """
    pass


@registry.register("7.2.72", text="स्तुसुधूञ्भ्यः परस्मैपदेषु।")
def rule_7_2_72(ctx=None):
    """
    7.2.72: स्तुसुधूञ्भ्यः परस्मैपदेषु।
    """
    pass


@registry.register("7.2.73", text="यमरमनमातां सक् च ।")
def rule_7_2_73(ctx=None):
    """
    7.2.73: यमरमनमातां सक् च ।
    """
    pass


@registry.register("7.2.74", text="स्मिपूङ्रञ्ज्वशां सनि ।")
def rule_7_2_74(ctx=None):
    """
    7.2.74: स्मिपूङ्रञ्ज्वशां सनि ।
    """
    pass


@registry.register("7.2.75", text="किरश्च पञ्चभ्यः ।")
def rule_7_2_75(ctx=None):
    """
    7.2.75: किरश्च पञ्चभ्यः ।
    """
    pass


@registry.register("7.2.76", text="रुदादिभ्यः सार्वधतुके ।")
def rule_7_2_76(ctx=None):
    """
    7.2.76: रुदादिभ्यः सार्वधतुके ।
    """
    pass


@registry.register("7.2.77", text="ईशः से।")
def rule_7_2_77(ctx=None):
    """
    7.2.77: ईशः से।
    """
    pass


@registry.register("7.2.78", text="ईडजनोर्ध्वे च ।")
def rule_7_2_78(ctx=None):
    """
    7.2.78: ईडजनोर्ध्वे च ।
    """
    pass


@registry.register("7.2.79", text="लिङः सलोपोऽनन्त्यस्य ।")
def rule_7_2_79(ctx=None):
    """
    7.2.79: लिङः सलोपोऽनन्त्यस्य ।
    """
    pass


@registry.register("7.2.80", text="अतोयेयः ।")
def rule_7_2_80(ctx=None):
    """
    7.2.80: अतोयेयः ।
    """
    pass


@registry.register("7.2.81", text="आतोङितः ।")
def rule_7_2_81(ctx=None):
    """
    7.2.81: आतोङितः ।
    """
    pass


@registry.register("7.2.82", text="आनेमुक् ।")
def rule_7_2_82(ctx=None):
    """
    7.2.82: आनेमुक् ।
    """
    pass


@registry.register("7.2.83", text="ईदासः ।")
def rule_7_2_83(ctx=None):
    """
    7.2.83: ईदासः ।
    """
    pass


@registry.register("7.2.84", text="अष्टन आ विभक्तौ।")
def rule_7_2_84(ctx=None):
    """
    7.2.84: अष्टन आ विभक्तौ।
    """
    pass


@registry.register("7.2.85", text="रायोहलि ।")
def rule_7_2_85(ctx=None):
    """
    7.2.85: रायोहलि ।
    """
    pass


@registry.register("7.2.86", text="युष्मदस्मदोरनादेशे।")
def rule_7_2_86(ctx=None):
    """
    7.2.86: युष्मदस्मदोरनादेशे।
    """
    pass


@registry.register("7.2.87", text="द्वितीयायां च ।")
def rule_7_2_87(ctx=None):
    """
    7.2.87: द्वितीयायां च ।
    """
    pass


@registry.register("7.2.88", text="प्रथमायाश्च द्विवचनेभाषायाम् ।")
def rule_7_2_88(ctx=None):
    """
    7.2.88: प्रथमायाश्च द्विवचनेभाषायाम् ।
    """
    pass


@registry.register("7.2.89", text="योऽचि ।")
def rule_7_2_89(ctx=None):
    """
    7.2.89: योऽचि ।
    """
    pass


@registry.register("7.2.90", text="शेषेलोपः ।")
def rule_7_2_90(ctx=None):
    """
    7.2.90: शेषेलोपः ।
    """
    pass


@registry.register("7.2.91", text="मपर्यन्तस्य ।")
def rule_7_2_91(ctx=None):
    """
    7.2.91: मपर्यन्तस्य ।
    """
    pass


@registry.register("7.2.92", text="युवावौद्विवचने।")
def rule_7_2_92(ctx=None):
    """
    7.2.92: युवावौद्विवचने।
    """
    pass


@registry.register("7.2.93", text="यूयवयौजसि ।")
def rule_7_2_93(ctx=None):
    """
    7.2.93: यूयवयौजसि ।
    """
    pass


@registry.register("7.2.94", text="त्वाहौसौ।")
def rule_7_2_94(ctx=None):
    """
    7.2.94: त्वाहौसौ।
    """
    pass


@registry.register("7.2.95", text="तुभ्यमह्यौङयि ।")
def rule_7_2_95(ctx=None):
    """
    7.2.95: तुभ्यमह्यौङयि ।
    """
    pass


@registry.register("7.2.96", text="तवममौङसि ।")
def rule_7_2_96(ctx=None):
    """
    7.2.96: तवममौङसि ।
    """
    pass


@registry.register("7.2.97", text="त्वमावेकवचने।")
def rule_7_2_97(ctx=None):
    """
    7.2.97: त्वमावेकवचने।
    """
    pass


@registry.register("7.2.98", text="प्रतयोत्तरपदयोश्च ।")
def rule_7_2_98(ctx=None):
    """
    7.2.98: प्रतयोत्तरपदयोश्च ।
    """
    pass


@registry.register("7.2.99", text="त्रिचतुरोः स्त्रियां तिसृचतसृ ।")
def rule_7_2_99(ctx=None):
    """
    7.2.99: त्रिचतुरोः स्त्रियां तिसृचतसृ ।
    """
    pass


@registry.register("7.2.100", text="अचि र ऋतः ।")
def rule_7_2_100(ctx=None):
    """
    7.2.100: अचि र ऋतः ।
    """
    pass


@registry.register("7.2.101", text="जराया जरसन्यतरस्याम् ।")
def rule_7_2_101(ctx=None):
    """
    7.2.101: जराया जरसन्यतरस्याम् ।
    """
    pass


@registry.register("7.2.102", text="त्यदादीनामः ।")
def rule_7_2_102(ctx=None):
    """
    7.2.102: त्यदादीनामः ।
    """
    pass


@registry.register("7.2.103", text="किमः कः ।")
def rule_7_2_103(ctx=None):
    """
    7.2.103: किमः कः ।
    """
    pass


@registry.register("7.2.104", text="कु तिहोः ।")
def rule_7_2_104(ctx=None):
    """
    7.2.104: कु तिहोः ।
    """
    pass


@registry.register("7.2.105", text="क्वाति ।")
def rule_7_2_105(ctx=None):
    """
    7.2.105: क्वाति ।
    """
    pass


@registry.register("7.2.106", text="तदोः सः सावनन्त्ययोः ।")
def rule_7_2_106(ctx=None):
    """
    7.2.106: तदोः सः सावनन्त्ययोः ।
    """
    pass


@registry.register("7.2.107", text="अदस औसुलोपश्च ।")
def rule_7_2_107(ctx=None):
    """
    7.2.107: अदस औसुलोपश्च ।
    """
    pass


@registry.register("7.2.108", text="इदमोमः ।")
def rule_7_2_108(ctx=None):
    """
    7.2.108: इदमोमः ।
    """
    pass


@registry.register("7.2.109", text="दश्च ।")
def rule_7_2_109(ctx=None):
    """
    7.2.109: दश्च ।
    """
    pass


@registry.register("7.2.110", text="यः सौ।")
def rule_7_2_110(ctx=None):
    """
    7.2.110: यः सौ।
    """
    pass


@registry.register("7.2.111", text="इदोऽय् पुंसि ।")
def rule_7_2_111(ctx=None):
    """
    7.2.111: इदोऽय् पुंसि ।
    """
    pass


@registry.register("7.2.112", text="अनाप्यकः ।")
def rule_7_2_112(ctx=None):
    """
    7.2.112: अनाप्यकः ।
    """
    pass


@registry.register("7.2.113", text="हलि लोपः ।")
def rule_7_2_113(ctx=None):
    """
    7.2.113: हलि लोपः ।
    """
    pass


@registry.register("7.2.114", text="मृजेर्वृद्धिः ।")
def rule_7_2_114(ctx=None):
    """
    7.2.114: मृजेर्वृद्धिः ।
    """
    pass


@registry.register("7.2.115", text="अचोञ्णिति ।")
def rule_7_2_115(ctx=None):
    """
    7.2.115: अचोञ्णिति ।
    """
    pass


@registry.register("7.2.116", text="अत उपधायाः ।")
def rule_7_2_116(ctx=None):
    """
    7.2.116: अत उपधायाः ।
    """
    pass


@registry.register("7.2.117", text="तद्धितेष्वचामादेः ।")
def rule_7_2_117(ctx=None):
    """
    7.2.117: तद्धितेष्वचामादेः ।
    """
    pass


@registry.register("7.2.118", text="किति च ।")
def rule_7_2_118(ctx=None):
    """
    7.2.118: किति च ।
    """
    pass


@registry.register("7.3.1", text="देविकाशिंशपादित्यवाड्दीर्घसत्रश्रेयसामात् ।")
def rule_7_3_1(ctx=None):
    """
    7.3.1: देविकाशिंशपादित्यवाड्दीर्घसत्रश्रेयसामात् ।
    """
    pass


@registry.register("7.3.2", text="केकयमित्त्रयुप्रलयानां यादेरियः ।")
def rule_7_3_2(ctx=None):
    """
    7.3.2: केकयमित्त्रयुप्रलयानां यादेरियः ।
    """
    pass


@registry.register("7.3.3", text="न य्वाभ्यां पदान्ताभ्याम् पूर्वौ तुताभ्यामैच् ।")
def rule_7_3_3(ctx=None):
    """
    7.3.3: न य्वाभ्यां पदान्ताभ्याम् पूर्वौ तुताभ्यामैच् ।
    """
    pass


@registry.register("7.3.4", text="द्वारादीनां च ।")
def rule_7_3_4(ctx=None):
    """
    7.3.4: द्वारादीनां च ।
    """
    pass


@registry.register("7.3.5", text="न्यग्रोधस्य च केवलस्य ।")
def rule_7_3_5(ctx=None):
    """
    7.3.5: न्यग्रोधस्य च केवलस्य ।
    """
    pass


@registry.register("7.3.6", text="न कर्मव्यतिहारे।")
def rule_7_3_6(ctx=None):
    """
    7.3.6: न कर्मव्यतिहारे।
    """
    pass


@registry.register("7.3.7", text="स्वागतादीनां च ।")
def rule_7_3_7(ctx=None):
    """
    7.3.7: स्वागतादीनां च ।
    """
    pass


@registry.register("7.3.8", text="श्वादेरिञि ।")
def rule_7_3_8(ctx=None):
    """
    7.3.8: श्वादेरिञि ।
    """
    pass


@registry.register("7.3.9", text="पदान्तस्यान्यतरस्याम् ।")
def rule_7_3_9(ctx=None):
    """
    7.3.9: पदान्तस्यान्यतरस्याम् ।
    """
    pass


@registry.register("7.3.10", text="उत्तरपदस्य ।")
def rule_7_3_10(ctx=None):
    """
    7.3.10: उत्तरपदस्य ।
    """
    pass


@registry.register("7.3.11", text="अवयवादृतोः ।")
def rule_7_3_11(ctx=None):
    """
    7.3.11: अवयवादृतोः ।
    """
    pass


@registry.register("7.3.12", text="सुसर्वार्धाज्जनपदस्य ।")
def rule_7_3_12(ctx=None):
    """
    7.3.12: सुसर्वार्धाज्जनपदस्य ।
    """
    pass


@registry.register("7.3.13", text="दिशोऽमद्राणाम् ।")
def rule_7_3_13(ctx=None):
    """
    7.3.13: दिशोऽमद्राणाम् ।
    """
    pass


@registry.register("7.3.14", text="प्राचां ग्रामनगराणाम् ।")
def rule_7_3_14(ctx=None):
    """
    7.3.14: प्राचां ग्रामनगराणाम् ।
    """
    pass


@registry.register("7.3.15", text="संख्यायाः संवत्सरसंख्यस्य च ।")
def rule_7_3_15(ctx=None):
    """
    7.3.15: संख्यायाः संवत्सरसंख्यस्य च ।
    """
    pass


@registry.register("7.3.16", text="वर्षस्याभविष्यति ।")
def rule_7_3_16(ctx=None):
    """
    7.3.16: वर्षस्याभविष्यति ।
    """
    pass


@registry.register("7.3.17", text="परिमाणान्तस्यासंज्ञाशाणयोः ।")
def rule_7_3_17(ctx=None):
    """
    7.3.17: परिमाणान्तस्यासंज्ञाशाणयोः ।
    """
    pass


@registry.register("7.3.18", text="जेप्रोष्ठपदानाम् ।")
def rule_7_3_18(ctx=None):
    """
    7.3.18: जेप्रोष्ठपदानाम् ।
    """
    pass


@registry.register("7.3.19", text="हृद्भगसिन्ध्वन्तेपूर्वपदस्य च ।")
def rule_7_3_19(ctx=None):
    """
    7.3.19: हृद्भगसिन्ध्वन्तेपूर्वपदस्य च ।
    """
    pass


@registry.register("7.3.20", text="अनुशतिकादीनां च ।")
def rule_7_3_20(ctx=None):
    """
    7.3.20: अनुशतिकादीनां च ।
    """
    pass


@registry.register("7.3.21", text="देवताद्वंद्वेच ।")
def rule_7_3_21(ctx=None):
    """
    7.3.21: देवताद्वंद्वेच ।
    """
    pass


@registry.register("7.3.22", text="नेन्द्रस्य परस्य ।")
def rule_7_3_22(ctx=None):
    """
    7.3.22: नेन्द्रस्य परस्य ।
    """
    pass


@registry.register("7.3.23", text="दीर्घाच्च वरुणस्य ।")
def rule_7_3_23(ctx=None):
    """
    7.3.23: दीर्घाच्च वरुणस्य ।
    """
    pass


@registry.register("7.3.24", text="प्राचां नगरान्ते।")
def rule_7_3_24(ctx=None):
    """
    7.3.24: प्राचां नगरान्ते।
    """
    pass


@registry.register("7.3.25", text="जङ्गलधेनुवलजान्तस्य विभाषितमुत्तरम् ।")
def rule_7_3_25(ctx=None):
    """
    7.3.25: जङ्गलधेनुवलजान्तस्य विभाषितमुत्तरम् ।
    """
    pass


@registry.register("7.3.26", text="अर्धात् परिमाणस्य पूर्वस्य तुवा ।")
def rule_7_3_26(ctx=None):
    """
    7.3.26: अर्धात् परिमाणस्य पूर्वस्य तुवा ।
    """
    pass


@registry.register("7.3.27", text="नातः परस्य ।")
def rule_7_3_27(ctx=None):
    """
    7.3.27: नातः परस्य ।
    """
    pass


@registry.register("7.3.28", text="प्रवाहणस्य ढे।")
def rule_7_3_28(ctx=None):
    """
    7.3.28: प्रवाहणस्य ढे।
    """
    pass


@registry.register("7.3.29", text="तत्प्रत्ययस्य च ।")
def rule_7_3_29(ctx=None):
    """
    7.3.29: तत्प्रत्ययस्य च ।
    """
    pass


@registry.register("7.3.30", text="नञः शुचीश्वरक्षेत्रज्ञकुशलनिपुणानाम् ।")
def rule_7_3_30(ctx=None):
    """
    7.3.30: नञः शुचीश्वरक्षेत्रज्ञकुशलनिपुणानाम् ।
    """
    pass


@registry.register("7.3.31", text="यथातथयथापुरयोः पर्यायेण ।")
def rule_7_3_31(ctx=None):
    """
    7.3.31: यथातथयथापुरयोः पर्यायेण ।
    """
    pass


@registry.register("7.3.32", text="हनस्तोऽचिण्णलोः ।")
def rule_7_3_32(ctx=None):
    """
    7.3.32: हनस्तोऽचिण्णलोः ।
    """
    pass


@registry.register("7.3.33", text="आतोयुक् चिङ्कृतोः ।")
def rule_7_3_33(ctx=None):
    """
    7.3.33: आतोयुक् चिङ्कृतोः ।
    """
    pass


@registry.register("7.3.34", text="नोदात्तोपदेशस्य मान्तस्यानाचमेः ।")
def rule_7_3_34(ctx=None):
    """
    7.3.34: नोदात्तोपदेशस्य मान्तस्यानाचमेः ।
    """
    pass


@registry.register("7.3.35", text="जनिवध्योश्च ।")
def rule_7_3_35(ctx=None):
    """
    7.3.35: जनिवध्योश्च ।
    """
    pass


@registry.register("7.3.36", text="अर्त्तिह्रीब्लीरीक्नूयीक्ष्माय्यातां पुङ्णौ।")
def rule_7_3_36(ctx=None):
    """
    7.3.36: अर्त्तिह्रीब्लीरीक्नूयीक्ष्माय्यातां पुङ्णौ।
    """
    pass


@registry.register("7.3.37", text="शाच्छासाह्वाव्यावेपां युक् ।")
def rule_7_3_37(ctx=None):
    """
    7.3.37: शाच्छासाह्वाव्यावेपां युक् ।
    """
    pass


@registry.register("7.3.38", text="वोविधूननेजुक् ।")
def rule_7_3_38(ctx=None):
    """
    7.3.38: वोविधूननेजुक् ।
    """
    pass


@registry.register("7.3.39", text="लीलोर्नुग्लुकावन्यतरस्यां स्नेहविपातने।")
def rule_7_3_39(ctx=None):
    """
    7.3.39: लीलोर्नुग्लुकावन्यतरस्यां स्नेहविपातने।
    """
    pass


@registry.register("7.3.40", text="भियोहेतुभयेषुक् ।")
def rule_7_3_40(ctx=None):
    """
    7.3.40: भियोहेतुभयेषुक् ।
    """
    pass


@registry.register("7.3.41", text="स्फायोवः ।")
def rule_7_3_41(ctx=None):
    """
    7.3.41: स्फायोवः ।
    """
    pass


@registry.register("7.3.42", text="शदेरगतौतः ।")
def rule_7_3_42(ctx=None):
    """
    7.3.42: शदेरगतौतः ।
    """
    pass


@registry.register("7.3.43", text="रुहः पोऽन्यतरस्याम् ।")
def rule_7_3_43(ctx=None):
    """
    7.3.43: रुहः पोऽन्यतरस्याम् ।
    """
    pass


@registry.register("7.3.44", text="प्रत्ययस्थात् कात् पूर्वस्यात इदाप्यसुपः ।")
def rule_7_3_44(ctx=None):
    """
    7.3.44: प्रत्ययस्थात् कात् पूर्वस्यात इदाप्यसुपः ।
    """
    pass


@registry.register("7.3.45", text="न यासयोः ।")
def rule_7_3_45(ctx=None):
    """
    7.3.45: न यासयोः ।
    """
    pass


@registry.register("7.3.46", text="उदीचामातः स्थानेयकपूर्वायाः ।")
def rule_7_3_46(ctx=None):
    """
    7.3.46: उदीचामातः स्थानेयकपूर्वायाः ।
    """
    pass


@registry.register("7.3.47", text="भस्त्रैषाऽजाज्ञाद्वास्वानञ्पूर्वाणामपि ।")
def rule_7_3_47(ctx=None):
    """
    7.3.47: भस्त्रैषाऽजाज्ञाद्वास्वानञ्पूर्वाणामपि ।
    """
    pass


@registry.register("7.3.48", text="अभाषितपुंस्काच्च ।")
def rule_7_3_48(ctx=None):
    """
    7.3.48: अभाषितपुंस्काच्च ।
    """
    pass


@registry.register("7.3.49", text="आदाचार्याणाम् ।")
def rule_7_3_49(ctx=None):
    """
    7.3.49: आदाचार्याणाम् ।
    """
    pass


@registry.register("7.3.50", text="ठस्येकः ।")
def rule_7_3_50(ctx=None):
    """
    7.3.50: ठस्येकः ।
    """
    pass


@registry.register("7.3.51", text="इसुसुक्तान्तात् कः ।")
def rule_7_3_51(ctx=None):
    """
    7.3.51: इसुसुक्तान्तात् कः ।
    """
    pass


@registry.register("7.3.52", text="चजोः कु घिन्ण्यतोः ।")
def rule_7_3_52(ctx=None):
    """
    7.3.52: चजोः कु घिन्ण्यतोः ।
    """
    pass


@registry.register("7.3.53", text="न्यङ्क्वादीनां च ।")
def rule_7_3_53(ctx=None):
    """
    7.3.53: न्यङ्क्वादीनां च ।
    """
    pass


@registry.register("7.3.54", text="होहन्तेर्ञ्णिन्नेषु।")
def rule_7_3_54(ctx=None):
    """
    7.3.54: होहन्तेर्ञ्णिन्नेषु।
    """
    pass


@registry.register("7.3.55", text="अभ्यासाच्च ।")
def rule_7_3_55(ctx=None):
    """
    7.3.55: अभ्यासाच्च ।
    """
    pass


@registry.register("7.3.56", text="हेरचङि ।")
def rule_7_3_56(ctx=None):
    """
    7.3.56: हेरचङि ।
    """
    pass


@registry.register("7.3.57", text="सन्लिटोर्जेः ।")
def rule_7_3_57(ctx=None):
    """
    7.3.57: सन्लिटोर्जेः ।
    """
    pass


@registry.register("7.3.58", text="विभाषा चेः ।")
def rule_7_3_58(ctx=None):
    """
    7.3.58: विभाषा चेः ।
    """
    pass


@registry.register("7.3.59", text="न क्वादेः ।")
def rule_7_3_59(ctx=None):
    """
    7.3.59: न क्वादेः ।
    """
    pass


@registry.register("7.3.60", text="अजिवृज्योश्च ।")
def rule_7_3_60(ctx=None):
    """
    7.3.60: अजिवृज्योश्च ।
    """
    pass


@registry.register("7.3.61", text="भुजन्युब्जौपाण्युपतापयोः ।")
def rule_7_3_61(ctx=None):
    """
    7.3.61: भुजन्युब्जौपाण्युपतापयोः ।
    """
    pass


@registry.register("7.3.62", text="प्रयाजानुयाजौयज्ञाङ्गे ।")
def rule_7_3_62(ctx=None):
    """
    7.3.62: प्रयाजानुयाजौयज्ञाङ्गे ।
    """
    pass


@registry.register("7.3.63", text="वञ्चेर्गतौ।")
def rule_7_3_63(ctx=None):
    """
    7.3.63: वञ्चेर्गतौ।
    """
    pass


@registry.register("7.3.64", text="ओक उचः के ।")
def rule_7_3_64(ctx=None):
    """
    7.3.64: ओक उचः के ।
    """
    pass


@registry.register("7.3.65", text="ण्य आवश्यके ।")
def rule_7_3_65(ctx=None):
    """
    7.3.65: ण्य आवश्यके ।
    """
    pass


@registry.register("7.3.66", text="यजयाचरुचप्रवचर्चश्च ।")
def rule_7_3_66(ctx=None):
    """
    7.3.66: यजयाचरुचप्रवचर्चश्च ।
    """
    pass


@registry.register("7.3.67", text="वचोऽशब्दसंज्ञायाम् ।")
def rule_7_3_67(ctx=None):
    """
    7.3.67: वचोऽशब्दसंज्ञायाम् ।
    """
    pass


@registry.register("7.3.68", text="प्रयोज्यनियोज्यौशक्यार्थे ।")
def rule_7_3_68(ctx=None):
    """
    7.3.68: प्रयोज्यनियोज्यौशक्यार्थे ।
    """
    pass


@registry.register("7.3.69", text="भोज्यं भक्ष्ये।")
def rule_7_3_69(ctx=None):
    """
    7.3.69: भोज्यं भक्ष्ये।
    """
    pass


@registry.register("7.3.70", text="घोर्लोपोलेटि वा ।")
def rule_7_3_70(ctx=None):
    """
    7.3.70: घोर्लोपोलेटि वा ।
    """
    pass


@registry.register("7.3.71", text="ओतः श्यनि ।")
def rule_7_3_71(ctx=None):
    """
    7.3.71: ओतः श्यनि ।
    """
    pass


@registry.register("7.3.72", text="क्सस्याचि ।")
def rule_7_3_72(ctx=None):
    """
    7.3.72: क्सस्याचि ।
    """
    pass


@registry.register("7.3.73", text="लुग्वा दुहदिहलिहगुहामात्मनेपदेदन्त्ये।")
def rule_7_3_73(ctx=None):
    """
    7.3.73: लुग्वा दुहदिहलिहगुहामात्मनेपदेदन्त्ये।
    """
    pass


@registry.register("7.3.74", text="शमामष्टानां दीर्घः श्यनि ।")
def rule_7_3_74(ctx=None):
    """
    7.3.74: शमामष्टानां दीर्घः श्यनि ।
    """
    pass


@registry.register("7.3.75", text="ष्ठिवुक्लम्याचमां शिति ।")
def rule_7_3_75(ctx=None):
    """
    7.3.75: ष्ठिवुक्लम्याचमां शिति ।
    """
    pass


@registry.register("7.3.76", text="क्रमः परस्मैपदेषु।")
def rule_7_3_76(ctx=None):
    """
    7.3.76: क्रमः परस्मैपदेषु।
    """
    pass


@registry.register("7.3.77", text="इषुगमियमां छः ।")
def rule_7_3_77(ctx=None):
    """
    7.3.77: इषुगमियमां छः ।
    """
    pass


@registry.register("7.3.78", text="पाघ्राध्मास्थाम्नादाण्दृश्यर्त्तिसर्त्तिशदसदां पिबजिघ्रधमतिष्ठमनयच्छपश्यर्च्छधौशीयसीदाः ।")
def rule_7_3_78(ctx=None):
    """
    7.3.78: पाघ्राध्मास्थाम्नादाण्दृश्यर्त्तिसर्त्तिशदसदां पिबजिघ्रधमतिष्ठमनयच्छपश्यर्च्छधौशीयसीदाः ।
    """
    pass


@registry.register("7.3.79", text="ज्ञाजनोर्जा ।")
def rule_7_3_79(ctx=None):
    """
    7.3.79: ज्ञाजनोर्जा ।
    """
    pass


@registry.register("7.3.80", text="प्वादीनां ह्रस्वः ।")
def rule_7_3_80(ctx=None):
    """
    7.3.80: प्वादीनां ह्रस्वः ।
    """
    pass


@registry.register("7.3.81", text="मीनातेर्निगमे।")
def rule_7_3_81(ctx=None):
    """
    7.3.81: मीनातेर्निगमे।
    """
    pass


@registry.register("7.3.82", text="मिदेर्गुणः ।")
def rule_7_3_82(ctx=None):
    """
    7.3.82: मिदेर्गुणः ।
    """
    pass


@registry.register("7.3.83", text="जुसि च ।")
def rule_7_3_83(ctx=None):
    """
    7.3.83: जुसि च ।
    """
    pass


@registry.register("7.3.84", text="सार्वधातुकार्धधातुकयोः ।")
def rule_7_3_84(ctx=None):
    """
    7.3.84: सार्वधातुकार्धधातुकयोः ।
    """
    pass


@registry.register("7.3.85", text="जाग्रोऽविचिण्णल्ङित्सु।")
def rule_7_3_85(ctx=None):
    """
    7.3.85: जाग्रोऽविचिण्णल्ङित्सु।
    """
    pass


@registry.register("7.3.86", text="पुगन्तलघूपधस्य च ।")
def rule_7_3_86(ctx=None):
    """
    7.3.86: पुगन्तलघूपधस्य च ।
    """
    pass


@registry.register("7.3.87", text="नाभ्यस्तस्याचि पिति सार्वधातुके ।")
def rule_7_3_87(ctx=None):
    """
    7.3.87: नाभ्यस्तस्याचि पिति सार्वधातुके ।
    """
    pass


@registry.register("7.3.88", text="भूसुवोस्तिङि ।")
def rule_7_3_88(ctx=None):
    """
    7.3.88: भूसुवोस्तिङि ।
    """
    pass


@registry.register("7.3.89", text="उतोवृद्धिर्लुकि हलि ।")
def rule_7_3_89(ctx=None):
    """
    7.3.89: उतोवृद्धिर्लुकि हलि ।
    """
    pass


@registry.register("7.3.90", text="ऊर्णोतेर्विभाषा ।")
def rule_7_3_90(ctx=None):
    """
    7.3.90: ऊर्णोतेर्विभाषा ।
    """
    pass


@registry.register("7.3.91", text="गुणोऽपृक्ते ।")
def rule_7_3_91(ctx=None):
    """
    7.3.91: गुणोऽपृक्ते ।
    """
    pass


@registry.register("7.3.92", text="तृणह इम् ।")
def rule_7_3_92(ctx=None):
    """
    7.3.92: तृणह इम् ।
    """
    pass


@registry.register("7.3.93", text="ब्रुव ईट् ।")
def rule_7_3_93(ctx=None):
    """
    7.3.93: ब्रुव ईट् ।
    """
    pass


@registry.register("7.3.94", text="यङोवा ।")
def rule_7_3_94(ctx=None):
    """
    7.3.94: यङोवा ।
    """
    pass


@registry.register("7.3.95", text="तुरुस्तुशम्यमः सार्वधातुके ।")
def rule_7_3_95(ctx=None):
    """
    7.3.95: तुरुस्तुशम्यमः सार्वधातुके ।
    """
    pass


@registry.register("7.3.96", text="अस्तिसिचोऽपृक्ते ।")
def rule_7_3_96(ctx=None):
    """
    7.3.96: अस्तिसिचोऽपृक्ते ।
    """
    pass


@registry.register("7.3.97", text="बहुलं छन्दसि ।")
def rule_7_3_97(ctx=None):
    """
    7.3.97: बहुलं छन्दसि ।
    """
    pass


@registry.register("7.3.98", text="रुदश्च पञ्चभ्यः ।")
def rule_7_3_98(ctx=None):
    """
    7.3.98: रुदश्च पञ्चभ्यः ।
    """
    pass


@registry.register("7.3.99", text="अड्गार्ग्यगालवयोः ।")
def rule_7_3_99(ctx=None):
    """
    7.3.99: अड्गार्ग्यगालवयोः ।
    """
    pass


@registry.register("7.3.100", text="अदः सर्वेषाम् ।")
def rule_7_3_100(ctx=None):
    """
    7.3.100: अदः सर्वेषाम् ।
    """
    pass


@registry.register("7.3.101", text="अतोदीर्घो यञि ।")
def rule_7_3_101(ctx=None):
    """
    7.3.101: अतोदीर्घो यञि ।
    """
    pass


@registry.register("7.3.102", text="सुपि च ।")
def rule_7_3_102(ctx=None):
    """
    7.3.102: सुपि च ।
    """
    pass


@registry.register("7.3.103", text="बहुवचनेझल्येत् ।")
def rule_7_3_103(ctx=None):
    """
    7.3.103: बहुवचनेझल्येत् ।
    """
    pass


@registry.register("7.3.104", text="ओऽसि च ।")
def rule_7_3_104(ctx=None):
    """
    7.3.104: ओऽसि च ।
    """
    pass


@registry.register("7.3.105", text="आङि चापः ।")
def rule_7_3_105(ctx=None):
    """
    7.3.105: आङि चापः ।
    """
    pass


@registry.register("7.3.106", text="सम्बुद्धौच ।")
def rule_7_3_106(ctx=None):
    """
    7.3.106: सम्बुद्धौच ।
    """
    pass


@registry.register("7.3.107", text="अम्बाऽर्थनद्योर्ह्रस्वः ।")
def rule_7_3_107(ctx=None):
    """
    7.3.107: अम्बाऽर्थनद्योर्ह्रस्वः ।
    """
    pass


@registry.register("7.3.108", text="ह्रस्वस्य गुणः ।")
def rule_7_3_108(ctx=None):
    """
    7.3.108: ह्रस्वस्य गुणः ।
    """
    pass


@registry.register("7.3.109", text="जसि च ।")
def rule_7_3_109(ctx=None):
    """
    7.3.109: जसि च ।
    """
    pass


@registry.register("7.3.110", text="ऋतोङिसर्वनामस्थानयोः ।")
def rule_7_3_110(ctx=None):
    """
    7.3.110: ऋतोङिसर्वनामस्थानयोः ।
    """
    pass


@registry.register("7.3.111", text="घेर्ङिति ।")
def rule_7_3_111(ctx=None):
    """
    7.3.111: घेर्ङिति ।
    """
    pass


@registry.register("7.3.112", text="आण्नद्याः ।")
def rule_7_3_112(ctx=None):
    """
    7.3.112: आण्नद्याः ।
    """
    pass


@registry.register("7.3.113", text="याडापः ।")
def rule_7_3_113(ctx=None):
    """
    7.3.113: याडापः ।
    """
    pass


@registry.register("7.3.114", text="सर्वनाम्नः स्याड्ढ्रस्वश्च ।")
def rule_7_3_114(ctx=None):
    """
    7.3.114: सर्वनाम्नः स्याड्ढ्रस्वश्च ।
    """
    pass


@registry.register("7.3.115", text="विभाषा द्वितीयातृतीयाभ्याम् ।")
def rule_7_3_115(ctx=None):
    """
    7.3.115: विभाषा द्वितीयातृतीयाभ्याम् ।
    """
    pass


@registry.register("7.3.116", text="ङेराम्नद्याम्नीभ्यः ।")
def rule_7_3_116(ctx=None):
    """
    7.3.116: ङेराम्नद्याम्नीभ्यः ।
    """
    pass


@registry.register("7.3.117", text="इदुद्भ्याम् ।")
def rule_7_3_117(ctx=None):
    """
    7.3.117: इदुद्भ्याम् ।
    """
    pass


@registry.register("7.3.118", text="औत् ।")
def rule_7_3_118(ctx=None):
    """
    7.3.118: औत् ।
    """
    pass


@registry.register("7.3.119", text="अच्च घेः ।")
def rule_7_3_119(ctx=None):
    """
    7.3.119: अच्च घेः ।
    """
    pass


@registry.register("7.3.120", text="आङोनाऽस्त्रियाम् ।")
def rule_7_3_120(ctx=None):
    """
    7.3.120: आङोनाऽस्त्रियाम् ।
    """
    pass


@registry.register("7.4.1", text="णौचङ्युपधाया ह्रस्वः ।")
def rule_7_4_1(ctx=None):
    """
    7.4.1: णौचङ्युपधाया ह्रस्वः ।
    """
    pass


@registry.register("7.4.2", text="नाग्लोपिशास्वृदिताम् ।")
def rule_7_4_2(ctx=None):
    """
    7.4.2: नाग्लोपिशास्वृदिताम् ।
    """
    pass


@registry.register("7.4.3", text="भ्राजभासभाषदीपजीवमीलपीडामन्यतरस्याम् ।")
def rule_7_4_3(ctx=None):
    """
    7.4.3: भ्राजभासभाषदीपजीवमीलपीडामन्यतरस्याम् ।
    """
    pass


@registry.register("7.4.4", text="लोपः पिबतेरीच्चाभ्यासस्य ।")
def rule_7_4_4(ctx=None):
    """
    7.4.4: लोपः पिबतेरीच्चाभ्यासस्य ।
    """
    pass


@registry.register("7.4.5", text="तिष्ठतेरित् ।")
def rule_7_4_5(ctx=None):
    """
    7.4.5: तिष्ठतेरित् ।
    """
    pass


@registry.register("7.4.6", text="जिघ्रतेर्वा ।")
def rule_7_4_6(ctx=None):
    """
    7.4.6: जिघ्रतेर्वा ।
    """
    pass


@registry.register("7.4.7", text="उरृत् ।")
def rule_7_4_7(ctx=None):
    """
    7.4.7: उरृत् ।
    """
    pass


@registry.register("7.4.8", text="नित्यं छन्दसि ।")
def rule_7_4_8(ctx=None):
    """
    7.4.8: नित्यं छन्दसि ।
    """
    pass


@registry.register("7.4.9", text="दयतेर्दिगि लिटि ।")
def rule_7_4_9(ctx=None):
    """
    7.4.9: दयतेर्दिगि लिटि ।
    """
    pass


@registry.register("7.4.10", text="ऋतश्च संयोगादेर्गुणः ।")
def rule_7_4_10(ctx=None):
    """
    7.4.10: ऋतश्च संयोगादेर्गुणः ।
    """
    pass


@registry.register("7.4.11", text="ऋच्छत्यॄताम् ।")
def rule_7_4_11(ctx=None):
    """
    7.4.11: ऋच्छत्यॄताम् ।
    """
    pass


@registry.register("7.4.12", text="श‍ृदॄप्रां ह्रस्वोवा ।")
def rule_7_4_12(ctx=None):
    """
    7.4.12: श‍ृदॄप्रां ह्रस्वोवा ।
    """
    pass


@registry.register("7.4.13", text="केऽणः ।")
def rule_7_4_13(ctx=None):
    """
    7.4.13: केऽणः ।
    """
    pass


@registry.register("7.4.14", text="न कपि ।")
def rule_7_4_14(ctx=None):
    """
    7.4.14: न कपि ।
    """
    pass


@registry.register("7.4.15", text="आपोऽन्यतरस्याम् ।")
def rule_7_4_15(ctx=None):
    """
    7.4.15: आपोऽन्यतरस्याम् ।
    """
    pass


@registry.register("7.4.16", text="ऋदृशोऽङि गुणः ।")
def rule_7_4_16(ctx=None):
    """
    7.4.16: ऋदृशोऽङि गुणः ।
    """
    pass


@registry.register("7.4.17", text="अस्यतेस्थुक् ।")
def rule_7_4_17(ctx=None):
    """
    7.4.17: अस्यतेस्थुक् ।
    """
    pass


@registry.register("7.4.18", text="श्वयतेरः ।")
def rule_7_4_18(ctx=None):
    """
    7.4.18: श्वयतेरः ।
    """
    pass


@registry.register("7.4.19", text="पतः पुम् ।")
def rule_7_4_19(ctx=None):
    """
    7.4.19: पतः पुम् ।
    """
    pass


@registry.register("7.4.20", text="वच उम् ।")
def rule_7_4_20(ctx=None):
    """
    7.4.20: वच उम् ।
    """
    pass


@registry.register("7.4.21", text="शीङः सार्वधातुके गुणः ।")
def rule_7_4_21(ctx=None):
    """
    7.4.21: शीङः सार्वधातुके गुणः ।
    """
    pass


@registry.register("7.4.22", text="अयङ् यि क्ङिति ।")
def rule_7_4_22(ctx=None):
    """
    7.4.22: अयङ् यि क्ङिति ।
    """
    pass


@registry.register("7.4.23", text="उपसर्गाद्ध्रस्व ऊहतेः ।")
def rule_7_4_23(ctx=None):
    """
    7.4.23: उपसर्गाद्ध्रस्व ऊहतेः ।
    """
    pass


@registry.register("7.4.24", text="एतेर्लिङि ।")
def rule_7_4_24(ctx=None):
    """
    7.4.24: एतेर्लिङि ।
    """
    pass


@registry.register("7.4.25", text="अकृत्सार्वधातुकयोर्दीर्घः ।")
def rule_7_4_25(ctx=None):
    """
    7.4.25: अकृत्सार्वधातुकयोर्दीर्घः ।
    """
    pass


@registry.register("7.4.26", text="च्वौच ।")
def rule_7_4_26(ctx=None):
    """
    7.4.26: च्वौच ।
    """
    pass


@registry.register("7.4.27", text="रीङ् ऋतः ।")
def rule_7_4_27(ctx=None):
    """
    7.4.27: रीङ् ऋतः ।
    """
    pass


@registry.register("7.4.28", text="रिङ् शयग्लिङ्क्षु ।")
def rule_7_4_28(ctx=None):
    """
    7.4.28: रिङ् शयग्लिङ्क्षु ।
    """
    pass


@registry.register("7.4.29", text="गुणोऽर्तिसंयोगाद्योः ।")
def rule_7_4_29(ctx=None):
    """
    7.4.29: गुणोऽर्तिसंयोगाद्योः ।
    """
    pass


@registry.register("7.4.30", text="यङि च ।")
def rule_7_4_30(ctx=None):
    """
    7.4.30: यङि च ।
    """
    pass


@registry.register("7.4.31", text="ई घ्राध्मोः ।")
def rule_7_4_31(ctx=None):
    """
    7.4.31: ई घ्राध्मोः ।
    """
    pass


@registry.register("7.4.32", text="अस्य च्वौ।")
def rule_7_4_32(ctx=None):
    """
    7.4.32: अस्य च्वौ।
    """
    pass


@registry.register("7.4.33", text="क्यचि च ।")
def rule_7_4_33(ctx=None):
    """
    7.4.33: क्यचि च ।
    """
    pass


@registry.register("7.4.34", text="अशनायोदन्यधनाया बुभुक्षापिपासागर्द्धेषु।")
def rule_7_4_34(ctx=None):
    """
    7.4.34: अशनायोदन्यधनाया बुभुक्षापिपासागर्द्धेषु।
    """
    pass


@registry.register("7.4.35", text="न च्छन्दस्यपुत्रस्य ।")
def rule_7_4_35(ctx=None):
    """
    7.4.35: न च्छन्दस्यपुत्रस्य ।
    """
    pass


@registry.register("7.4.36", text="दुरस्युर्द्रविणस्युर्वृषण्यतिरिषण्यति ।")
def rule_7_4_36(ctx=None):
    """
    7.4.36: दुरस्युर्द्रविणस्युर्वृषण्यतिरिषण्यति ।
    """
    pass


@registry.register("7.4.37", text="अश्वाघस्यात् ।")
def rule_7_4_37(ctx=None):
    """
    7.4.37: अश्वाघस्यात् ।
    """
    pass


@registry.register("7.4.38", text="देवसुम्नयोर्यजुषि काठके ।")
def rule_7_4_38(ctx=None):
    """
    7.4.38: देवसुम्नयोर्यजुषि काठके ।
    """
    pass


@registry.register("7.4.39", text="कव्यध्वरपृतनस्यर्चि लोपः ।")
def rule_7_4_39(ctx=None):
    """
    7.4.39: कव्यध्वरपृतनस्यर्चि लोपः ।
    """
    pass


@registry.register("7.4.40", text="द्यतिस्यतिमास्थामित्ति किति ।")
def rule_7_4_40(ctx=None):
    """
    7.4.40: द्यतिस्यतिमास्थामित्ति किति ।
    """
    pass


@registry.register("7.4.41", text="शाछोरन्यतरस्याम् ।")
def rule_7_4_41(ctx=None):
    """
    7.4.41: शाछोरन्यतरस्याम् ।
    """
    pass


@registry.register("7.4.42", text="दधातेर्हिः ।")
def rule_7_4_42(ctx=None):
    """
    7.4.42: दधातेर्हिः ।
    """
    pass


@registry.register("7.4.43", text="जहातेश्च क्त्वि ।")
def rule_7_4_43(ctx=None):
    """
    7.4.43: जहातेश्च क्त्वि ।
    """
    pass


@registry.register("7.4.44", text="विभाषा छन्दसि ।")
def rule_7_4_44(ctx=None):
    """
    7.4.44: विभाषा छन्दसि ।
    """
    pass


@registry.register("7.4.45", text="सुधितवसुधितनेमधितधिष्वधिषीय च ।")
def rule_7_4_45(ctx=None):
    """
    7.4.45: सुधितवसुधितनेमधितधिष्वधिषीय च ।
    """
    pass


@registry.register("7.4.46", text="दोदद् घोः ।")
def rule_7_4_46(ctx=None):
    """
    7.4.46: दोदद् घोः ।
    """
    pass


@registry.register("7.4.47", text="अच उपसर्गात्तः ।")
def rule_7_4_47(ctx=None):
    """
    7.4.47: अच उपसर्गात्तः ।
    """
    pass


@registry.register("7.4.48", text="अपोभि ।")
def rule_7_4_48(ctx=None):
    """
    7.4.48: अपोभि ।
    """
    pass


@registry.register("7.4.49", text="सः स्यार्द्धधातुके ।")
def rule_7_4_49(ctx=None):
    """
    7.4.49: सः स्यार्द्धधातुके ।
    """
    pass


@registry.register("7.4.50", text="तासस्त्योर्लोपः ।")
def rule_7_4_50(ctx=None):
    """
    7.4.50: तासस्त्योर्लोपः ।
    """
    pass


@registry.register("7.4.51", text="रि च ।")
def rule_7_4_51(ctx=None):
    """
    7.4.51: रि च ।
    """
    pass


@registry.register("7.4.52", text="ह एति ।")
def rule_7_4_52(ctx=None):
    """
    7.4.52: ह एति ।
    """
    pass


@registry.register("7.4.53", text="यीवर्णयोर्दीधीवेव्योः ।")
def rule_7_4_53(ctx=None):
    """
    7.4.53: यीवर्णयोर्दीधीवेव्योः ।
    """
    pass


@registry.register("7.4.54", text="सनि मीमाघुरभलभशकपतपदामच इस् ।")
def rule_7_4_54(ctx=None):
    """
    7.4.54: सनि मीमाघुरभलभशकपतपदामच इस् ।
    """
    pass


@registry.register("7.4.55", text="आप्ज्ञप्यृधामीत् ।")
def rule_7_4_55(ctx=None):
    """
    7.4.55: आप्ज्ञप्यृधामीत् ।
    """
    pass


@registry.register("7.4.56", text="दम्भ इच्च ।")
def rule_7_4_56(ctx=None):
    """
    7.4.56: दम्भ इच्च ।
    """
    pass


@registry.register("7.4.57", text="मुचोऽकर्मकस्य गुणोवा ।")
def rule_7_4_57(ctx=None):
    """
    7.4.57: मुचोऽकर्मकस्य गुणोवा ।
    """
    pass


@registry.register("7.4.58", text="अत्र लोपोऽभ्यासस्य ।")
def rule_7_4_58(ctx=None):
    """
    7.4.58: अत्र लोपोऽभ्यासस्य ।
    """
    pass


@registry.register("7.4.59", text="ह्रस्वः ।")
def rule_7_4_59(ctx=None):
    """
    7.4.59: ह्रस्वः ।
    """
    pass


@registry.register("7.4.60", text="हलादिः शेषः ।")
def rule_7_4_60(ctx=None):
    """
    7.4.60: हलादिः शेषः ।
    """
    pass


@registry.register("7.4.61", text="शर्पूर्वाः खयः ।")
def rule_7_4_61(ctx=None):
    """
    7.4.61: शर्पूर्वाः खयः ।
    """
    pass


@registry.register("7.4.62", text="कुहोश्चुः ।")
def rule_7_4_62(ctx=None):
    """
    7.4.62: कुहोश्चुः ।
    """
    pass


@registry.register("7.4.63", text="न कवतेर्यङि ।")
def rule_7_4_63(ctx=None):
    """
    7.4.63: न कवतेर्यङि ।
    """
    pass


@registry.register("7.4.64", text="कृषेश्छन्दसि ।")
def rule_7_4_64(ctx=None):
    """
    7.4.64: कृषेश्छन्दसि ।
    """
    pass


@registry.register("7.4.65", text="दाधर्तिदर्धर्तिदर्धर्षिबोभूतुतेतिक्तेऽलर्ष्यापनीफणत् संसनिष्यदत्करिक्रत्कनिक्रदद्भरिभ्रद्दविध्वतोदविद्युतत् तरित्रतःसरीसृपतंवरीवृजन्मर्मृज्यागनीगन्तीति च ।")
def rule_7_4_65(ctx=None):
    """
    7.4.65: दाधर्तिदर्धर्तिदर्धर्षिबोभूतुतेतिक्तेऽलर्ष्यापनीफणत् संसनिष्यदत्करिक्रत्कनिक्रदद्भरिभ्रद्दविध्वतोदविद्युतत् तरित्रतःसरीसृपतंवरीवृजन्मर्मृज्यागनीगन्तीति च ।
    """
    pass


@registry.register("7.4.66", text="उरत् ।")
def rule_7_4_66(ctx=None):
    """
    7.4.66: उरत् ।
    """
    pass


@registry.register("7.4.67", text="द्युतिस्वाप्योः सम्प्रसारणम् ।")
def rule_7_4_67(ctx=None):
    """
    7.4.67: द्युतिस्वाप्योः सम्प्रसारणम् ।
    """
    pass


@registry.register("7.4.68", text="व्यथोलिटि ।")
def rule_7_4_68(ctx=None):
    """
    7.4.68: व्यथोलिटि ।
    """
    pass


@registry.register("7.4.69", text="दीर्घ इणः किति ।")
def rule_7_4_69(ctx=None):
    """
    7.4.69: दीर्घ इणः किति ।
    """
    pass


@registry.register("7.4.70", text="अतः आदेः ।")
def rule_7_4_70(ctx=None):
    """
    7.4.70: अतः आदेः ।
    """
    pass


@registry.register("7.4.71", text="तस्मान्नुड् द्विहलः ।")
def rule_7_4_71(ctx=None):
    """
    7.4.71: तस्मान्नुड् द्विहलः ।
    """
    pass


@registry.register("7.4.72", text="अश्नोतेश्च ।")
def rule_7_4_72(ctx=None):
    """
    7.4.72: अश्नोतेश्च ।
    """
    pass


@registry.register("7.4.73", text="भवतेरः ।")
def rule_7_4_73(ctx=None):
    """
    7.4.73: भवतेरः ।
    """
    pass


@registry.register("7.4.74", text="ससूवेति निगमे।")
def rule_7_4_74(ctx=None):
    """
    7.4.74: ससूवेति निगमे।
    """
    pass


@registry.register("7.4.75", text="निजां त्रयाणां गुणः श्लौ।")
def rule_7_4_75(ctx=None):
    """
    7.4.75: निजां त्रयाणां गुणः श्लौ।
    """
    pass


@registry.register("7.4.76", text="भृञामित् ।")
def rule_7_4_76(ctx=None):
    """
    7.4.76: भृञामित् ।
    """
    pass


@registry.register("7.4.77", text="अर्तिपिपर्त्योश्च ।")
def rule_7_4_77(ctx=None):
    """
    7.4.77: अर्तिपिपर्त्योश्च ।
    """
    pass


@registry.register("7.4.78", text="बहुलं छन्दसि ।")
def rule_7_4_78(ctx=None):
    """
    7.4.78: बहुलं छन्दसि ।
    """
    pass


@registry.register("7.4.79", text="सन्यतः ।")
def rule_7_4_79(ctx=None):
    """
    7.4.79: सन्यतः ।
    """
    pass


@registry.register("7.4.80", text="ओः पुयण्ज्यपरे।")
def rule_7_4_80(ctx=None):
    """
    7.4.80: ओः पुयण्ज्यपरे।
    """
    pass


@registry.register("7.4.81", text="स्रवतिश‍ृणोतिद्रवतिप्रवतिप्लवतिच्यवतीनां वा ।")
def rule_7_4_81(ctx=None):
    """
    7.4.81: स्रवतिश‍ृणोतिद्रवतिप्रवतिप्लवतिच्यवतीनां वा ।
    """
    pass


@registry.register("7.4.82", text="गुणोयङ्लुकोः ।")
def rule_7_4_82(ctx=None):
    """
    7.4.82: गुणोयङ्लुकोः ।
    """
    pass


@registry.register("7.4.83", text="दीर्घोऽकितः ।")
def rule_7_4_83(ctx=None):
    """
    7.4.83: दीर्घोऽकितः ।
    """
    pass


@registry.register("7.4.84", text="नीग्वञ्चुस्रंसुध्वंसुभ्रंसुकसपतपदस्कन्दाम् ।")
def rule_7_4_84(ctx=None):
    """
    7.4.84: नीग्वञ्चुस्रंसुध्वंसुभ्रंसुकसपतपदस्कन्दाम् ।
    """
    pass


@registry.register("7.4.85", text="नुगतोऽनुनासिकान्तस्य ।")
def rule_7_4_85(ctx=None):
    """
    7.4.85: नुगतोऽनुनासिकान्तस्य ।
    """
    pass


@registry.register("7.4.86", text="जपजभदहदशभञ्जपशां च ।")
def rule_7_4_86(ctx=None):
    """
    7.4.86: जपजभदहदशभञ्जपशां च ।
    """
    pass


@registry.register("7.4.87", text="चरफलोश्च ।")
def rule_7_4_87(ctx=None):
    """
    7.4.87: चरफलोश्च ।
    """
    pass


@registry.register("7.4.88", text="उत् परस्यातः ।")
def rule_7_4_88(ctx=None):
    """
    7.4.88: उत् परस्यातः ।
    """
    pass


@registry.register("7.4.89", text="ति च ।")
def rule_7_4_89(ctx=None):
    """
    7.4.89: ति च ।
    """
    pass


@registry.register("7.4.90", text="रीगृदुपधस्य च ।")
def rule_7_4_90(ctx=None):
    """
    7.4.90: रीगृदुपधस्य च ।
    """
    pass


@registry.register("7.4.91", text="रुग्रिकौच लुकि ।")
def rule_7_4_91(ctx=None):
    """
    7.4.91: रुग्रिकौच लुकि ।
    """
    pass


@registry.register("7.4.92", text="ऋतश्च ।")
def rule_7_4_92(ctx=None):
    """
    7.4.92: ऋतश्च ।
    """
    pass


@registry.register("7.4.93", text="सन्वल्लघुनि चङ्परेऽनग्लोपे।")
def rule_7_4_93(ctx=None):
    """
    7.4.93: सन्वल्लघुनि चङ्परेऽनग्लोपे।
    """
    pass


@registry.register("7.4.94", text="दीर्घो लघोः ।")
def rule_7_4_94(ctx=None):
    """
    7.4.94: दीर्घो लघोः ।
    """
    pass


@registry.register("7.4.95", text="अत् स्मृदृत्वरप्रथम्रदस्तॄस्पशाम् ।")
def rule_7_4_95(ctx=None):
    """
    7.4.95: अत् स्मृदृत्वरप्रथम्रदस्तॄस्पशाम् ।
    """
    pass


@registry.register("7.4.96", text="विभाषा वेष्टिचेष्ट्योः ।")
def rule_7_4_96(ctx=None):
    """
    7.4.96: विभाषा वेष्टिचेष्ट्योः ।
    """
    pass


@registry.register("7.4.97", text="ई च गणः ।")
def rule_7_4_97(ctx=None):
    """
    7.4.97: ई च गणः ।
    """
    pass



# Auto-generated by scripts/scaffold_roots.py for Gana 6
from . import registry


@registry.register("6.1", root="तुद", meaning="व्यथने", gana="Tudadi")
def root_6_1():
    """
    6.1 तुद व्यथने 
    """
    return "तुद"


@registry.register("6.2", root="णुद", meaning="प्रेरणे", gana="Tudadi")
def root_6_2():
    """
    6.2 णुद प्रेरणे 
    """
    return "णुद"


@registry.register("6.3", root="दिश", meaning="अतिसर्जने", gana="Tudadi")
def root_6_3():
    """
    6.3 दिश अतिसर्जने 
    """
    return "दिश"


@registry.register("6.4", root="भ्रस्ज", meaning="पाके", gana="Tudadi")
def root_6_4():
    """
    6.4 भ्रस्ज पाके 
    """
    return "भ्रस्ज"


@registry.register("6.5", root="क्षिप", meaning="प्रेरणे", gana="Tudadi")
def root_6_5():
    """
    6.5 क्षिप प्रेरणे 
    """
    return "क्षिप"


@registry.register("6.6", root="कृष", meaning="विलेखने", gana="Tudadi")
def root_6_6():
    """
    6.6 कृष विलेखने 
    """
    return "कृष"


@registry.register("6.7", root="ऋषी", meaning="गतौ", gana="Tudadi")
def root_6_7():
    """
    6.7 ऋषी गतौ 
    """
    return "ऋषी"


@registry.register("6.8", root="जुषी", meaning="प्रीतिसेवनयोः", gana="Tudadi")
def root_6_8():
    """
    6.8 जुषी प्रीतिसेवनयोः 
    """
    return "जुषी"


@registry.register("6.9", root="ओविजी", meaning="भयचलनयोः", gana="Tudadi")
def root_6_9():
    """
    6.9 ओविजी भयचलनयोः 
    """
    return "ओविजी"


@registry.register("6.11", root="ओलस्जी", meaning="व्रीडायाम् व्रीडे", gana="Tudadi")
def root_6_11():
    """
    6.11 ओलस्जी व्रीडायाम् व्रीडे 
    """
    return "ओलस्जी"


@registry.register("6.12", root="ओव्रश्चू", meaning="छेदने", gana="Tudadi")
def root_6_12():
    """
    6.12 ओव्रश्चू छेदने 
    """
    return "ओव्रश्चू"


@registry.register("6.13", root="व्यच", meaning="व्याजीकरणे", gana="Tudadi")
def root_6_13():
    """
    6.13 व्यच व्याजीकरणे 
    """
    return "व्यच"


@registry.register("6.14", root="उछि", meaning="उञ्छे", gana="Tudadi")
def root_6_14():
    """
    6.14 उछि उञ्छे 
    """
    return "उछि"


@registry.register("6.15", root="उछी", meaning="विवासे", gana="Tudadi")
def root_6_15():
    """
    6.15 उछी विवासे 
    """
    return "उछी"


@registry.register("6.16", root="ऋछ", meaning="गतीन्द्रियप्रलयमूर्तिभावेषु", gana="Tudadi")
def root_6_16():
    """
    6.16 ऋछ गतीन्द्रियप्रलयमूर्तिभावेषु 
    """
    return "ऋछ"


@registry.register("6.17", root="मिछ", meaning="उत्क्लेशे", gana="Tudadi")
def root_6_17():
    """
    6.17 मिछ उत्क्लेशे 
    """
    return "मिछ"


@registry.register("6.20", root="झर्झ", meaning="परिभाषणभर्त्सनयोः", gana="Tudadi")
def root_6_20():
    """
    6.20 झर्झ परिभाषणभर्त्सनयोः 
    """
    return "झर्झ"


@registry.register("6.21", root="त्वच", meaning="संवरणे", gana="Tudadi")
def root_6_21():
    """
    6.21 त्वच संवरणे 
    """
    return "त्वच"


@registry.register("6.22", root="ऋच", meaning="स्तुतौ", gana="Tudadi")
def root_6_22():
    """
    6.22 ऋच स्तुतौ 
    """
    return "ऋच"


@registry.register("6.23", root="उब्ज", meaning="आर्जवे", gana="Tudadi")
def root_6_23():
    """
    6.23 उब्ज आर्जवे 
    """
    return "उब्ज"


@registry.register("6.24", root="उज्झऽ", meaning="उद्झ उत्सर्गे", gana="Tudadi")
def root_6_24():
    """
    6.24 उज्झऽ उद्झ उत्सर्गे 
    """
    return "उज्झऽ"


@registry.register("6.25", root="लुभ", meaning="विमोहने", gana="Tudadi")
def root_6_25():
    """
    6.25 लुभ विमोहने 
    """
    return "लुभ"


@registry.register("6.26", root="रिफ", meaning="कत्थनयुद्धनिन्दाहिंसादानेषु", gana="Tudadi")
def root_6_26():
    """
    6.26 रिफ कत्थनयुद्धनिन्दाहिंसादानेषु 
    """
    return "रिफ"


@registry.register("6.27", root="रिह", meaning="इत्येके", gana="Tudadi")
def root_6_27():
    """
    6.27 रिह इत्येके 
    """
    return "रिह"


@registry.register("6.29", root="तृम्पऽ", meaning="तृप्तौ", gana="Tudadi")
def root_6_29():
    """
    6.29 तृम्पऽ तृप्तौ 
    """
    return "तृम्पऽ"


@registry.register("6.31", root="तृम्फ", meaning="इत्येके", gana="Tudadi")
def root_6_31():
    """
    6.31 तृम्फ इत्येके 
    """
    return "तृम्फ"


@registry.register("6.35", root="तुम्फ", meaning="हिंसायाम्", gana="Tudadi")
def root_6_35():
    """
    6.35 तुम्फ हिंसायाम् 
    """
    return "तुम्फ"


@registry.register("6.37", root="दृम्प", meaning="उत्क्लेशे", gana="Tudadi")
def root_6_37():
    """
    6.37 दृम्प उत्क्लेशे 
    """
    return "दृम्प"


@registry.register("6.39", root="दृम्फ", meaning="इत्येके", gana="Tudadi")
def root_6_39():
    """
    6.39 दृम्फ इत्येके 
    """
    return "दृम्फ"


@registry.register("6.41", root="ऋम्फ", meaning="हिंसायाम्", gana="Tudadi")
def root_6_41():
    """
    6.41 ऋम्फ हिंसायाम् 
    """
    return "ऋम्फ"


@registry.register("6.43", root="गुम्फ", meaning="ग्रन्थे", gana="Tudadi")
def root_6_43():
    """
    6.43 गुम्फ ग्रन्थे 
    """
    return "गुम्फ"


@registry.register("6.45", root="उम्भ", meaning="पूरणे", gana="Tudadi")
def root_6_45():
    """
    6.45 उम्भ पूरणे 
    """
    return "उम्भ"


@registry.register("6.47", root="शुम्भ", meaning="शोभार्थे", gana="Tudadi")
def root_6_47():
    """
    6.47 शुम्भ शोभार्थे 
    """
    return "शुम्भ"


@registry.register("6.48", root="दृभी", meaning="ग्रन्थे", gana="Tudadi")
def root_6_48():
    """
    6.48 दृभी ग्रन्थे 
    """
    return "दृभी"


@registry.register("6.49", root="चृती", meaning="हिंसाग्रन्थनयोः", gana="Tudadi")
def root_6_49():
    """
    6.49 चृती हिंसाग्रन्थनयोः 
    """
    return "चृती"


@registry.register("6.50", root="विध", meaning="विधाने", gana="Tudadi")
def root_6_50():
    """
    6.50 विध विधाने 
    """
    return "विध"


@registry.register("6.51", root="जुड", meaning="गतौ", gana="Tudadi")
def root_6_51():
    """
    6.51 जुड गतौ 
    """
    return "जुड"


@registry.register("6.52", root="जुन", meaning="इत्येके", gana="Tudadi")
def root_6_52():
    """
    6.52 जुन इत्येके 
    """
    return "जुन"


@registry.register("6.53", root="मृड", meaning="सुखने", gana="Tudadi")
def root_6_53():
    """
    6.53 मृड सुखने 
    """
    return "मृड"


@registry.register("6.54", root="पृड", meaning="च", gana="Tudadi")
def root_6_54():
    """
    6.54 पृड च 
    """
    return "पृड"


@registry.register("6.55", root="पृण", meaning="प्रीणने", gana="Tudadi")
def root_6_55():
    """
    6.55 पृण प्रीणने 
    """
    return "पृण"


@registry.register("6.56", root="वृण", meaning="च", gana="Tudadi")
def root_6_56():
    """
    6.56 वृण च 
    """
    return "वृण"


@registry.register("6.57", root="मृण", meaning="हिंसायाम्", gana="Tudadi")
def root_6_57():
    """
    6.57 मृण हिंसायाम् 
    """
    return "मृण"


@registry.register("6.58", root="तुण", meaning="कौटिल्ये", gana="Tudadi")
def root_6_58():
    """
    6.58 तुण कौटिल्ये 
    """
    return "तुण"


@registry.register("6.59", root="पुण", meaning="कर्मणि शुभे", gana="Tudadi")
def root_6_59():
    """
    6.59 पुण कर्मणि शुभे 
    """
    return "पुण"


@registry.register("6.60", root="मुण", meaning="प्रतिज्ञाने", gana="Tudadi")
def root_6_60():
    """
    6.60 मुण प्रतिज्ञाने 
    """
    return "मुण"


@registry.register("6.61", root="कुण", meaning="शब्दोपकरणयोः शब्दोपतापयोः", gana="Tudadi")
def root_6_61():
    """
    6.61 कुण शब्दोपकरणयोः शब्दोपतापयोः 
    """
    return "कुण"


@registry.register("6.62", root="शुन", meaning="गतौ", gana="Tudadi")
def root_6_62():
    """
    6.62 शुन गतौ 
    """
    return "शुन"


@registry.register("6.63", root="द्रुण", meaning="हिंसागतिकौटिल्येषु", gana="Tudadi")
def root_6_63():
    """
    6.63 द्रुण हिंसागतिकौटिल्येषु 
    """
    return "द्रुण"


@registry.register("6.65", root="घूर्ण", meaning="भ्रमणे", gana="Tudadi")
def root_6_65():
    """
    6.65 घूर्ण भ्रमणे 
    """
    return "घूर्ण"


@registry.register("6.66", root="षुर", meaning="ऐश्वर्यदीप्त्योः", gana="Tudadi")
def root_6_66():
    """
    6.66 षुर ऐश्वर्यदीप्त्योः 
    """
    return "षुर"


@registry.register("6.67", root="कुर", meaning="शब्दे", gana="Tudadi")
def root_6_67():
    """
    6.67 कुर शब्दे 
    """
    return "कुर"


@registry.register("6.68", root="खुर", meaning="छेदने", gana="Tudadi")
def root_6_68():
    """
    6.68 खुर छेदने 
    """
    return "खुर"


@registry.register("6.69", root="मुर", meaning="संवेष्टने सञ्चेष्टने", gana="Tudadi")
def root_6_69():
    """
    6.69 मुर संवेष्टने सञ्चेष्टने 
    """
    return "मुर"


@registry.register("6.70", root="क्षुर", meaning="विलेखने", gana="Tudadi")
def root_6_70():
    """
    6.70 क्षुर विलेखने 
    """
    return "क्षुर"


@registry.register("6.71", root="घुर", meaning="भीमार्थशब्दयोः", gana="Tudadi")
def root_6_71():
    """
    6.71 घुर भीमार्थशब्दयोः 
    """
    return "घुर"


@registry.register("6.72", root="पुर", meaning="अग्रगमने", gana="Tudadi")
def root_6_72():
    """
    6.72 पुर अग्रगमने 
    """
    return "पुर"


@registry.register("6.73", root="वृहू", meaning="उद्यमने", gana="Tudadi")
def root_6_73():
    """
    6.73 वृहू उद्यमने 
    """
    return "वृहू"


@registry.register("6.74", root="बृहू", meaning="इत्येके", gana="Tudadi")
def root_6_74():
    """
    6.74 बृहू इत्येके 
    """
    return "बृहू"


@registry.register("6.77", root="तृंहू", meaning="हिंसार्थाः", gana="Tudadi")
def root_6_77():
    """
    6.77 तृंहू हिंसार्थाः 
    """
    return "तृंहू"


@registry.register("6.78", root="इष", meaning="इषु इच्छायाम्", gana="Tudadi")
def root_6_78():
    """
    6.78 इष इषु इच्छायाम् 
    """
    return "इष"


@registry.register("6.79", root="मिष", meaning="स्पर्धायाम्", gana="Tudadi")
def root_6_79():
    """
    6.79 मिष स्पर्धायाम् 
    """
    return "मिष"


@registry.register("6.80", root="किल", meaning="श्वैत्यक्रीडनयोः श्वैत्ये", gana="Tudadi")
def root_6_80():
    """
    6.80 किल श्वैत्यक्रीडनयोः श्वैत्ये 
    """
    return "किल"


@registry.register("6.81", root="तिल", meaning="स्नेहने स्नेहे", gana="Tudadi")
def root_6_81():
    """
    6.81 तिल स्नेहने स्नेहे 
    """
    return "तिल"


@registry.register("6.82", root="चिल", meaning="वसने", gana="Tudadi")
def root_6_82():
    """
    6.82 चिल वसने 
    """
    return "चिल"


@registry.register("6.83", root="चल", meaning="विलसने", gana="Tudadi")
def root_6_83():
    """
    6.83 चल विलसने 
    """
    return "चल"


@registry.register("6.84", root="इल", meaning="स्वप्नक्षेपनयोः", gana="Tudadi")
def root_6_84():
    """
    6.84 इल स्वप्नक्षेपनयोः 
    """
    return "इल"


@registry.register("6.85", root="विल", meaning="संवरणे", gana="Tudadi")
def root_6_85():
    """
    6.85 विल संवरणे 
    """
    return "विल"


@registry.register("6.86", root="बिल", meaning="भेदने", gana="Tudadi")
def root_6_86():
    """
    6.86 बिल भेदने 
    """
    return "बिल"


@registry.register("6.87", root="णिल", meaning="गहने", gana="Tudadi")
def root_6_87():
    """
    6.87 णिल गहने 
    """
    return "णिल"


@registry.register("6.88", root="हिल", meaning="भावकरणे", gana="Tudadi")
def root_6_88():
    """
    6.88 हिल भावकरणे 
    """
    return "हिल"


@registry.register("6.90", root="षिल", meaning="उञ्छे", gana="Tudadi")
def root_6_90():
    """
    6.90 षिल उञ्छे 
    """
    return "षिल"


@registry.register("6.91", root="मिल", meaning="श्लेषणे", gana="Tudadi")
def root_6_91():
    """
    6.91 मिल श्लेषणे 
    """
    return "मिल"


@registry.register("6.92", root="लिख", meaning="अक्षरविन्यासे", gana="Tudadi")
def root_6_92():
    """
    6.92 लिख अक्षरविन्यासे 
    """
    return "लिख"


@registry.register("6.93", root="कुट", meaning="कौटिल्ये", gana="Tudadi")
def root_6_93():
    """
    6.93 कुट कौटिल्ये 
    """
    return "कुट"


@registry.register("6.94", root="पुट", meaning="संश्लेषणे", gana="Tudadi")
def root_6_94():
    """
    6.94 पुट संश्लेषणे 
    """
    return "पुट"


@registry.register("6.95", root="कुच", meaning="सङ्कोचने", gana="Tudadi")
def root_6_95():
    """
    6.95 कुच सङ्कोचने 
    """
    return "कुच"


@registry.register("6.96", root="गुज", meaning="शब्दे", gana="Tudadi")
def root_6_96():
    """
    6.96 गुज शब्दे 
    """
    return "गुज"


@registry.register("6.97", root="गुड", meaning="रक्षायाम्", gana="Tudadi")
def root_6_97():
    """
    6.97 गुड रक्षायाम् 
    """
    return "गुड"


@registry.register("6.98", root="डिप", meaning="क्षेपे", gana="Tudadi")
def root_6_98():
    """
    6.98 डिप क्षेपे 
    """
    return "डिप"


@registry.register("6.99", root="छुर", meaning="छेदने", gana="Tudadi")
def root_6_99():
    """
    6.99 छुर छेदने 
    """
    return "छुर"


@registry.register("6.100", root="स्फुट", meaning="विकसने", gana="Tudadi")
def root_6_100():
    """
    6.100 स्फुट विकसने 
    """
    return "स्फुट"


@registry.register("6.101", root="मुट", meaning="आक्षेपप्रमर्दनयोः", gana="Tudadi")
def root_6_101():
    """
    6.101 मुट आक्षेपप्रमर्दनयोः 
    """
    return "मुट"


@registry.register("6.102", root="त्रुट", meaning="छेदने", gana="Tudadi")
def root_6_102():
    """
    6.102 त्रुट छेदने 
    """
    return "त्रुट"


@registry.register("6.103", root="तुट", meaning="कलहकर्मणि", gana="Tudadi")
def root_6_103():
    """
    6.103 तुट कलहकर्मणि 
    """
    return "तुट"


@registry.register("6.105", root="छुट", meaning="छेदने", gana="Tudadi")
def root_6_105():
    """
    6.105 छुट छेदने 
    """
    return "छुट"


@registry.register("6.106", root="जुड", meaning="बन्धने", gana="Tudadi")
def root_6_106():
    """
    6.106 जुड बन्धने 
    """
    return "जुड"


@registry.register("6.107", root="जुट", meaning="इत्येके", gana="Tudadi")
def root_6_107():
    """
    6.107 जुट इत्येके 
    """
    return "जुट"


@registry.register("6.108", root="कड", meaning="मदे", gana="Tudadi")
def root_6_108():
    """
    6.108 कड मदे 
    """
    return "कड"


@registry.register("6.109", root="लुट", meaning="संश्लेषणे", gana="Tudadi")
def root_6_109():
    """
    6.109 लुट संश्लेषणे 
    """
    return "लुट"


@registry.register("6.110", root="लुठ", meaning="इत्येके", gana="Tudadi")
def root_6_110():
    """
    6.110 लुठ इत्येके 
    """
    return "लुठ"


@registry.register("6.111", root="लुड", meaning="इत्यन्ये", gana="Tudadi")
def root_6_111():
    """
    6.111 लुड इत्यन्ये 
    """
    return "लुड"


@registry.register("6.112", root="कृड", meaning="घनत्वे", gana="Tudadi")
def root_6_112():
    """
    6.112 कृड घनत्वे 
    """
    return "कृड"


@registry.register("6.113", root="कुड", meaning="बाल्ये", gana="Tudadi")
def root_6_113():
    """
    6.113 कुड बाल्ये 
    """
    return "कुड"


@registry.register("6.114", root="पुड", meaning="उत्सर्गे", gana="Tudadi")
def root_6_114():
    """
    6.114 पुड उत्सर्गे 
    """
    return "पुड"


@registry.register("6.115", root="घुट", meaning="प्रतिघाते", gana="Tudadi")
def root_6_115():
    """
    6.115 घुट प्रतिघाते 
    """
    return "घुट"


@registry.register("6.116", root="तुड", meaning="तोडने", gana="Tudadi")
def root_6_116():
    """
    6.116 तुड तोडने 
    """
    return "तुड"


@registry.register("6.118", root="स्थुड", meaning="संवरणे", gana="Tudadi")
def root_6_118():
    """
    6.118 स्थुड संवरणे 
    """
    return "स्थुड"


@registry.register("6.120", root="छुड", meaning="इत्येके", gana="Tudadi")
def root_6_120():
    """
    6.120 छुड इत्येके 
    """
    return "छुड"


@registry.register("6.122", root="स्फुल", meaning="सञ्चलने", gana="Tudadi")
def root_6_122():
    """
    6.122 स्फुल सञ्चलने 
    """
    return "स्फुल"


@registry.register("6.124", root="स्फल", meaning="इत्यन्ये", gana="Tudadi")
def root_6_124():
    """
    6.124 स्फल इत्यन्ये 
    """
    return "स्फल"


@registry.register("6.127", root="व्रुड", meaning="संवरणे", gana="Tudadi")
def root_6_127():
    """
    6.127 व्रुड संवरणे 
    """
    return "व्रुड"


@registry.register("6.129", root="भृड", meaning="निमज्जने इत्येके", gana="Tudadi")
def root_6_129():
    """
    6.129 भृड निमज्जने इत्येके 
    """
    return "भृड"


@registry.register("6.130", root="हुड", meaning="सङ्घाते", gana="Tudadi")
def root_6_130():
    """
    6.130 हुड सङ्घाते 
    """
    return "हुड"


@registry.register("6.131", root="गुरी", meaning="उद्यमने", gana="Tudadi")
def root_6_131():
    """
    6.131 गुरी उद्यमने 
    """
    return "गुरी"


@registry.register("6.132", root="णू", meaning="णु स्तुतौ", gana="Tudadi")
def root_6_132():
    """
    6.132 णू णु स्तुतौ 
    """
    return "णू"


@registry.register("6.133", root="धू", meaning="धु विधूनने", gana="Tudadi")
def root_6_133():
    """
    6.133 धू धु विधूनने 
    """
    return "धू"


@registry.register("6.134", root="गु", meaning="पुरीषोत्सर्गे", gana="Tudadi")
def root_6_134():
    """
    6.134 गु पुरीषोत्सर्गे 
    """
    return "गु"


@registry.register("6.135", root="ध्रु", meaning="गतिस्थैर्ययोः", gana="Tudadi")
def root_6_135():
    """
    6.135 ध्रु गतिस्थैर्ययोः 
    """
    return "ध्रु"


@registry.register("6.136", root="कुङ्", meaning="शब्दे", gana="Tudadi")
def root_6_136():
    """
    6.136 कुङ् शब्दे 
    """
    return "कुङ्"


@registry.register("6.137", root="कूङ्", meaning="इत्येके दीर्घान्त इति कैयटादयः", gana="Tudadi")
def root_6_137():
    """
    6.137 कूङ् इत्येके दीर्घान्त इति कैयटादयः 
    """
    return "कूङ्"


@registry.register("6.138", root="पृङ्", meaning="व्यायामे", gana="Tudadi")
def root_6_138():
    """
    6.138 पृङ् व्यायामे 
    """
    return "पृङ्"


@registry.register("6.139", root="मृङ्", meaning="प्राणत्यागे", gana="Tudadi")
def root_6_139():
    """
    6.139 मृङ् प्राणत्यागे 
    """
    return "मृङ्"


@registry.register("6.141", root="पि", meaning="गतौ", gana="Tudadi")
def root_6_141():
    """
    6.141 पि गतौ 
    """
    return "पि"


@registry.register("6.142", root="धि", meaning="धारणे", gana="Tudadi")
def root_6_142():
    """
    6.142 धि धारणे 
    """
    return "धि"


@registry.register("6.143", root="क्षि", meaning="निवासगत्योः", gana="Tudadi")
def root_6_143():
    """
    6.143 क्षि निवासगत्योः 
    """
    return "क्षि"


@registry.register("6.144", root="षू", meaning="प्रेरणे", gana="Tudadi")
def root_6_144():
    """
    6.144 षू प्रेरणे 
    """
    return "षू"


@registry.register("6.145", root="कृई", meaning="विक्षेपे निक्षेपे", gana="Tudadi")
def root_6_145():
    """
    6.145 कृई विक्षेपे निक्षेपे 
    """
    return "कृई"


@registry.register("6.146", root="गृई", meaning="निगरणे", gana="Tudadi")
def root_6_146():
    """
    6.146 गृई निगरणे 
    """
    return "गृई"


@registry.register("6.147", root="दृङ्", meaning="आदरे", gana="Tudadi")
def root_6_147():
    """
    6.147 दृङ् आदरे 
    """
    return "दृङ्"


@registry.register("6.148", root="धृङ्", meaning="अवस्थाने", gana="Tudadi")
def root_6_148():
    """
    6.148 धृङ् अवस्थाने 
    """
    return "धृङ्"


@registry.register("6.149", root="प्रछ", meaning="ज्ञीप्सायाम्", gana="Tudadi")
def root_6_149():
    """
    6.149 प्रछ ज्ञीप्सायाम् 
    """
    return "प्रछ"


@registry.register("6.150", root="सृज", meaning="विसर्गे", gana="Tudadi")
def root_6_150():
    """
    6.150 सृज विसर्गे 
    """
    return "सृज"


@registry.register("6.151", root="टुमस्जो", meaning="शुद्धौ", gana="Tudadi")
def root_6_151():
    """
    6.151 टुमस्जो शुद्धौ 
    """
    return "टुमस्जो"


@registry.register("6.152", root="रुजो", meaning="भङ्गे", gana="Tudadi")
def root_6_152():
    """
    6.152 रुजो भङ्गे 
    """
    return "रुजो"


@registry.register("6.153", root="भुजो", meaning="कौटिल्ये", gana="Tudadi")
def root_6_153():
    """
    6.153 भुजो कौटिल्ये 
    """
    return "भुजो"


@registry.register("6.154", root="छुप", meaning="स्पर्शे", gana="Tudadi")
def root_6_154():
    """
    6.154 छुप स्पर्शे 
    """
    return "छुप"


@registry.register("6.156", root="रिश", meaning="हिंसायाम्", gana="Tudadi")
def root_6_156():
    """
    6.156 रिश हिंसायाम् 
    """
    return "रिश"


@registry.register("6.157", root="लिश", meaning="गतौ", gana="Tudadi")
def root_6_157():
    """
    6.157 लिश गतौ 
    """
    return "लिश"


@registry.register("6.158", root="स्पृश", meaning="संस्पर्शने", gana="Tudadi")
def root_6_158():
    """
    6.158 स्पृश संस्पर्शने 
    """
    return "स्पृश"


@registry.register("6.159", root="विछ", meaning="गतौ", gana="Tudadi")
def root_6_159():
    """
    6.159 विछ गतौ 
    """
    return "विछ"


@registry.register("6.160", root="विश", meaning="प्रवेशने", gana="Tudadi")
def root_6_160():
    """
    6.160 विश प्रवेशने 
    """
    return "विश"


@registry.register("6.161", root="मृश", meaning="आमर्शणे", gana="Tudadi")
def root_6_161():
    """
    6.161 मृश आमर्शणे 
    """
    return "मृश"


@registry.register("6.162", root="णुद", meaning="प्रेरणे", gana="Tudadi")
def root_6_162():
    """
    6.162 णुद प्रेरणे 
    """
    return "णुद"


@registry.register("6.163", root="षदॢ", meaning="विशरणगत्यवसादनेषु", gana="Tudadi")
def root_6_163():
    """
    6.163 षदॢ विशरणगत्यवसादनेषु 
    """
    return "षदॢ"


@registry.register("6.164", root="शदॢ", meaning="शातने", gana="Tudadi")
def root_6_164():
    """
    6.164 शदॢ शातने 
    """
    return "शदॢ"


@registry.register("6.165", root="मिल", meaning="सङ्गमे सङ्गमने", gana="Tudadi")
def root_6_165():
    """
    6.165 मिल सङ्गमे सङ्गमने 
    """
    return "मिल"


@registry.register("6.166", root="मुचॢ", meaning="मोक्षणे मोचने", gana="Tudadi")
def root_6_166():
    """
    6.166 मुचॢ मोक्षणे मोचने 
    """
    return "मुचॢ"


@registry.register("6.167", root="लुपॢ", meaning="छेदने", gana="Tudadi")
def root_6_167():
    """
    6.167 लुपॢ छेदने 
    """
    return "लुपॢ"


@registry.register("6.168", root="विदॢ", meaning="लाभे", gana="Tudadi")
def root_6_168():
    """
    6.168 विदॢ लाभे 
    """
    return "विदॢ"


@registry.register("6.169", root="लिप", meaning="उपदेहे", gana="Tudadi")
def root_6_169():
    """
    6.169 लिप उपदेहे 
    """
    return "लिप"


@registry.register("6.170", root="षिच", meaning="क्षरणे", gana="Tudadi")
def root_6_170():
    """
    6.170 षिच क्षरणे 
    """
    return "षिच"


@registry.register("6.171", root="कृती", meaning="छेदने", gana="Tudadi")
def root_6_171():
    """
    6.171 कृती छेदने 
    """
    return "कृती"


@registry.register("6.172", root="खिद", meaning="परिघाते परिघातने", gana="Tudadi")
def root_6_172():
    """
    6.172 खिद परिघाते परिघातने 
    """
    return "खिद"


@registry.register("6.173", root="पिश", meaning="अवयवे", gana="Tudadi")
def root_6_173():
    """
    6.173 पिश अवयवे 
    """
    return "पिश"
